# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PayslipSummary(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "employee_id": "str",
        "payslip_id": "str",
        "first_name": "str",
        "last_name": "str",
        "employee_group": "str",
        "wages": "float",
        "deductions": "float",
        "tax": "float",
        "super": "float",
        "reimbursements": "float",
        "net_pay": "float",
        "updated_date_utc": "datetime[ms-format]",
    }

    attribute_map = {
        "employee_id": "EmployeeID",
        "payslip_id": "PayslipID",
        "first_name": "FirstName",
        "last_name": "LastName",
        "employee_group": "EmployeeGroup",
        "wages": "Wages",
        "deductions": "Deductions",
        "tax": "Tax",
        "super": "Super",
        "reimbursements": "Reimbursements",
        "net_pay": "NetPay",
        "updated_date_utc": "UpdatedDateUTC",
    }

    def __init__(
        self,
        employee_id=None,
        payslip_id=None,
        first_name=None,
        last_name=None,
        employee_group=None,
        wages=None,
        deductions=None,
        tax=None,
        super=None,
        reimbursements=None,
        net_pay=None,
        updated_date_utc=None,
    ):  # noqa: E501
        """PayslipSummary - a model defined in OpenAPI"""  # noqa: E501

        self._employee_id = None
        self._payslip_id = None
        self._first_name = None
        self._last_name = None
        self._employee_group = None
        self._wages = None
        self._deductions = None
        self._tax = None
        self._super = None
        self._reimbursements = None
        self._net_pay = None
        self._updated_date_utc = None
        self.discriminator = None

        if employee_id is not None:
            self.employee_id = employee_id
        if payslip_id is not None:
            self.payslip_id = payslip_id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if employee_group is not None:
            self.employee_group = employee_group
        if wages is not None:
            self.wages = wages
        if deductions is not None:
            self.deductions = deductions
        if tax is not None:
            self.tax = tax
        if super is not None:
            self.super = super
        if reimbursements is not None:
            self.reimbursements = reimbursements
        if net_pay is not None:
            self.net_pay = net_pay
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc

    @property
    def employee_id(self):
        """Gets the employee_id of this PayslipSummary.  # noqa: E501

        The Xero identifier for an employee  # noqa: E501

        :return: The employee_id of this PayslipSummary.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this PayslipSummary.

        The Xero identifier for an employee  # noqa: E501

        :param employee_id: The employee_id of this PayslipSummary.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def payslip_id(self):
        """Gets the payslip_id of this PayslipSummary.  # noqa: E501

        Xero identifier for the payslip  # noqa: E501

        :return: The payslip_id of this PayslipSummary.  # noqa: E501
        :rtype: str
        """
        return self._payslip_id

    @payslip_id.setter
    def payslip_id(self, payslip_id):
        """Sets the payslip_id of this PayslipSummary.

        Xero identifier for the payslip  # noqa: E501

        :param payslip_id: The payslip_id of this PayslipSummary.  # noqa: E501
        :type: str
        """

        self._payslip_id = payslip_id

    @property
    def first_name(self):
        """Gets the first_name of this PayslipSummary.  # noqa: E501

        First name of employee  # noqa: E501

        :return: The first_name of this PayslipSummary.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this PayslipSummary.

        First name of employee  # noqa: E501

        :param first_name: The first_name of this PayslipSummary.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this PayslipSummary.  # noqa: E501

        Last name of employee  # noqa: E501

        :return: The last_name of this PayslipSummary.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this PayslipSummary.

        Last name of employee  # noqa: E501

        :param last_name: The last_name of this PayslipSummary.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def employee_group(self):
        """Gets the employee_group of this PayslipSummary.  # noqa: E501

        Employee group name  # noqa: E501

        :return: The employee_group of this PayslipSummary.  # noqa: E501
        :rtype: str
        """
        return self._employee_group

    @employee_group.setter
    def employee_group(self, employee_group):
        """Sets the employee_group of this PayslipSummary.

        Employee group name  # noqa: E501

        :param employee_group: The employee_group of this PayslipSummary.  # noqa: E501
        :type: str
        """

        self._employee_group = employee_group

    @property
    def wages(self):
        """Gets the wages of this PayslipSummary.  # noqa: E501

        The Wages for the Payslip  # noqa: E501

        :return: The wages of this PayslipSummary.  # noqa: E501
        :rtype: float
        """
        return self._wages

    @wages.setter
    def wages(self, wages):
        """Sets the wages of this PayslipSummary.

        The Wages for the Payslip  # noqa: E501

        :param wages: The wages of this PayslipSummary.  # noqa: E501
        :type: float
        """

        self._wages = wages

    @property
    def deductions(self):
        """Gets the deductions of this PayslipSummary.  # noqa: E501

        The Deductions for the Payslip  # noqa: E501

        :return: The deductions of this PayslipSummary.  # noqa: E501
        :rtype: float
        """
        return self._deductions

    @deductions.setter
    def deductions(self, deductions):
        """Sets the deductions of this PayslipSummary.

        The Deductions for the Payslip  # noqa: E501

        :param deductions: The deductions of this PayslipSummary.  # noqa: E501
        :type: float
        """

        self._deductions = deductions

    @property
    def tax(self):
        """Gets the tax of this PayslipSummary.  # noqa: E501

        The Tax for the Payslip  # noqa: E501

        :return: The tax of this PayslipSummary.  # noqa: E501
        :rtype: float
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this PayslipSummary.

        The Tax for the Payslip  # noqa: E501

        :param tax: The tax of this PayslipSummary.  # noqa: E501
        :type: float
        """

        self._tax = tax

    @property
    def super(self):
        """Gets the super of this PayslipSummary.  # noqa: E501

        The Super for the Payslip  # noqa: E501

        :return: The super of this PayslipSummary.  # noqa: E501
        :rtype: float
        """
        return self._super

    @super.setter
    def super(self, super):
        """Sets the super of this PayslipSummary.

        The Super for the Payslip  # noqa: E501

        :param super: The super of this PayslipSummary.  # noqa: E501
        :type: float
        """

        self._super = super

    @property
    def reimbursements(self):
        """Gets the reimbursements of this PayslipSummary.  # noqa: E501

        The Reimbursements for the Payslip  # noqa: E501

        :return: The reimbursements of this PayslipSummary.  # noqa: E501
        :rtype: float
        """
        return self._reimbursements

    @reimbursements.setter
    def reimbursements(self, reimbursements):
        """Sets the reimbursements of this PayslipSummary.

        The Reimbursements for the Payslip  # noqa: E501

        :param reimbursements: The reimbursements of this PayslipSummary.  # noqa: E501
        :type: float
        """

        self._reimbursements = reimbursements

    @property
    def net_pay(self):
        """Gets the net_pay of this PayslipSummary.  # noqa: E501

        The NetPay for the Payslip  # noqa: E501

        :return: The net_pay of this PayslipSummary.  # noqa: E501
        :rtype: float
        """
        return self._net_pay

    @net_pay.setter
    def net_pay(self, net_pay):
        """Sets the net_pay of this PayslipSummary.

        The NetPay for the Payslip  # noqa: E501

        :param net_pay: The net_pay of this PayslipSummary.  # noqa: E501
        :type: float
        """

        self._net_pay = net_pay

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this PayslipSummary.  # noqa: E501

        Last modified timestamp  # noqa: E501

        :return: The updated_date_utc of this PayslipSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this PayslipSummary.

        Last modified timestamp  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this PayslipSummary.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class JournalLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "journal_line_id": "str",
        "account_id": "str",
        "account_code": "str",
        "account_type": "AccountType",
        "account_name": "str",
        "description": "str",
        "net_amount": "float",
        "gross_amount": "float",
        "tax_amount": "float",
        "tax_type": "str",
        "tax_name": "str",
        "tracking_categories": "list[TrackingCategory]",
    }

    attribute_map = {
        "journal_line_id": "JournalLineID",
        "account_id": "AccountID",
        "account_code": "AccountCode",
        "account_type": "AccountType",
        "account_name": "AccountName",
        "description": "Description",
        "net_amount": "NetAmount",
        "gross_amount": "GrossAmount",
        "tax_amount": "TaxAmount",
        "tax_type": "TaxType",
        "tax_name": "TaxName",
        "tracking_categories": "TrackingCategories",
    }

    def __init__(
        self,
        journal_line_id=None,
        account_id=None,
        account_code=None,
        account_type=None,
        account_name=None,
        description=None,
        net_amount=None,
        gross_amount=None,
        tax_amount=None,
        tax_type=None,
        tax_name=None,
        tracking_categories=None,
    ):  # noqa: E501
        """JournalLine - a model defined in OpenAPI"""  # noqa: E501

        self._journal_line_id = None
        self._account_id = None
        self._account_code = None
        self._account_type = None
        self._account_name = None
        self._description = None
        self._net_amount = None
        self._gross_amount = None
        self._tax_amount = None
        self._tax_type = None
        self._tax_name = None
        self._tracking_categories = None
        self.discriminator = None

        if journal_line_id is not None:
            self.journal_line_id = journal_line_id
        if account_id is not None:
            self.account_id = account_id
        if account_code is not None:
            self.account_code = account_code
        if account_type is not None:
            self.account_type = account_type
        if account_name is not None:
            self.account_name = account_name
        if description is not None:
            self.description = description
        if net_amount is not None:
            self.net_amount = net_amount
        if gross_amount is not None:
            self.gross_amount = gross_amount
        if tax_amount is not None:
            self.tax_amount = tax_amount
        if tax_type is not None:
            self.tax_type = tax_type
        if tax_name is not None:
            self.tax_name = tax_name
        if tracking_categories is not None:
            self.tracking_categories = tracking_categories

    @property
    def journal_line_id(self):
        """Gets the journal_line_id of this JournalLine.  # noqa: E501

        Xero identifier for Journal  # noqa: E501

        :return: The journal_line_id of this JournalLine.  # noqa: E501
        :rtype: str
        """
        return self._journal_line_id

    @journal_line_id.setter
    def journal_line_id(self, journal_line_id):
        """Sets the journal_line_id of this JournalLine.

        Xero identifier for Journal  # noqa: E501

        :param journal_line_id: The journal_line_id of this JournalLine.  # noqa: E501
        :type: str
        """

        self._journal_line_id = journal_line_id

    @property
    def account_id(self):
        """Gets the account_id of this JournalLine.  # noqa: E501

        See Accounts  # noqa: E501

        :return: The account_id of this JournalLine.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this JournalLine.

        See Accounts  # noqa: E501

        :param account_id: The account_id of this JournalLine.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def account_code(self):
        """Gets the account_code of this JournalLine.  # noqa: E501

        See Accounts  # noqa: E501

        :return: The account_code of this JournalLine.  # noqa: E501
        :rtype: str
        """
        return self._account_code

    @account_code.setter
    def account_code(self, account_code):
        """Sets the account_code of this JournalLine.

        See Accounts  # noqa: E501

        :param account_code: The account_code of this JournalLine.  # noqa: E501
        :type: str
        """

        self._account_code = account_code

    @property
    def account_type(self):
        """Gets the account_type of this JournalLine.  # noqa: E501


        :return: The account_type of this JournalLine.  # noqa: E501
        :rtype: AccountType
        """
        return self._account_type

    @account_type.setter
    def account_type(self, account_type):
        """Sets the account_type of this JournalLine.


        :param account_type: The account_type of this JournalLine.  # noqa: E501
        :type: AccountType
        """

        self._account_type = account_type

    @property
    def account_name(self):
        """Gets the account_name of this JournalLine.  # noqa: E501

        See AccountCodes  # noqa: E501

        :return: The account_name of this JournalLine.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this JournalLine.

        See AccountCodes  # noqa: E501

        :param account_name: The account_name of this JournalLine.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def description(self):
        """Gets the description of this JournalLine.  # noqa: E501

        The description from the source transaction line item. Only returned if populated.  # noqa: E501

        :return: The description of this JournalLine.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this JournalLine.

        The description from the source transaction line item. Only returned if populated.  # noqa: E501

        :param description: The description of this JournalLine.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def net_amount(self):
        """Gets the net_amount of this JournalLine.  # noqa: E501

        Net amount of journal line. This will be a positive value for a debit and negative for a credit  # noqa: E501

        :return: The net_amount of this JournalLine.  # noqa: E501
        :rtype: float
        """
        return self._net_amount

    @net_amount.setter
    def net_amount(self, net_amount):
        """Sets the net_amount of this JournalLine.

        Net amount of journal line. This will be a positive value for a debit and negative for a credit  # noqa: E501

        :param net_amount: The net_amount of this JournalLine.  # noqa: E501
        :type: float
        """

        self._net_amount = net_amount

    @property
    def gross_amount(self):
        """Gets the gross_amount of this JournalLine.  # noqa: E501

        Gross amount of journal line (NetAmount + TaxAmount).  # noqa: E501

        :return: The gross_amount of this JournalLine.  # noqa: E501
        :rtype: float
        """
        return self._gross_amount

    @gross_amount.setter
    def gross_amount(self, gross_amount):
        """Sets the gross_amount of this JournalLine.

        Gross amount of journal line (NetAmount + TaxAmount).  # noqa: E501

        :param gross_amount: The gross_amount of this JournalLine.  # noqa: E501
        :type: float
        """

        self._gross_amount = gross_amount

    @property
    def tax_amount(self):
        """Gets the tax_amount of this JournalLine.  # noqa: E501

        Total tax on a journal line  # noqa: E501

        :return: The tax_amount of this JournalLine.  # noqa: E501
        :rtype: float
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """Sets the tax_amount of this JournalLine.

        Total tax on a journal line  # noqa: E501

        :param tax_amount: The tax_amount of this JournalLine.  # noqa: E501
        :type: float
        """

        self._tax_amount = tax_amount

    @property
    def tax_type(self):
        """Gets the tax_type of this JournalLine.  # noqa: E501

        The tax type from TaxRates  # noqa: E501

        :return: The tax_type of this JournalLine.  # noqa: E501
        :rtype: str
        """
        return self._tax_type

    @tax_type.setter
    def tax_type(self, tax_type):
        """Sets the tax_type of this JournalLine.

        The tax type from TaxRates  # noqa: E501

        :param tax_type: The tax_type of this JournalLine.  # noqa: E501
        :type: str
        """

        self._tax_type = tax_type

    @property
    def tax_name(self):
        """Gets the tax_name of this JournalLine.  # noqa: E501

        see TaxRates  # noqa: E501

        :return: The tax_name of this JournalLine.  # noqa: E501
        :rtype: str
        """
        return self._tax_name

    @tax_name.setter
    def tax_name(self, tax_name):
        """Sets the tax_name of this JournalLine.

        see TaxRates  # noqa: E501

        :param tax_name: The tax_name of this JournalLine.  # noqa: E501
        :type: str
        """

        self._tax_name = tax_name

    @property
    def tracking_categories(self):
        """Gets the tracking_categories of this JournalLine.  # noqa: E501

        Optional Tracking Category – see Tracking. Any JournalLine can have a maximum of 2 <TrackingCategory> elements.  # noqa: E501

        :return: The tracking_categories of this JournalLine.  # noqa: E501
        :rtype: list[TrackingCategory]
        """
        return self._tracking_categories

    @tracking_categories.setter
    def tracking_categories(self, tracking_categories):
        """Sets the tracking_categories of this JournalLine.

        Optional Tracking Category – see Tracking. Any JournalLine can have a maximum of 2 <TrackingCategory> elements.  # noqa: E501

        :param tracking_categories: The tracking_categories of this JournalLine.  # noqa: E501
        :type: list[TrackingCategory]
        """

        self._tracking_categories = tracking_categories



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Timesheet(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "employee_id": "str",
        "start_date": "date[ms-format]",
        "end_date": "date[ms-format]",
        "status": "TimesheetStatus",
        "hours": "float",
        "timesheet_id": "str",
        "timesheet_lines": "list[TimesheetLine]",
        "updated_date_utc": "datetime[ms-format]",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "employee_id": "EmployeeID",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "status": "Status",
        "hours": "Hours",
        "timesheet_id": "TimesheetID",
        "timesheet_lines": "TimesheetLines",
        "updated_date_utc": "UpdatedDateUTC",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        employee_id=None,
        start_date=None,
        end_date=None,
        status=None,
        hours=None,
        timesheet_id=None,
        timesheet_lines=None,
        updated_date_utc=None,
        validation_errors=None,
    ):  # noqa: E501
        """Timesheet - a model defined in OpenAPI"""  # noqa: E501

        self._employee_id = None
        self._start_date = None
        self._end_date = None
        self._status = None
        self._hours = None
        self._timesheet_id = None
        self._timesheet_lines = None
        self._updated_date_utc = None
        self._validation_errors = None
        self.discriminator = None

        self.employee_id = employee_id
        self.start_date = start_date
        self.end_date = end_date
        if status is not None:
            self.status = status
        if hours is not None:
            self.hours = hours
        if timesheet_id is not None:
            self.timesheet_id = timesheet_id
        if timesheet_lines is not None:
            self.timesheet_lines = timesheet_lines
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def employee_id(self):
        """Gets the employee_id of this Timesheet.  # noqa: E501

        The Xero identifier for an employee  # noqa: E501

        :return: The employee_id of this Timesheet.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this Timesheet.

        The Xero identifier for an employee  # noqa: E501

        :param employee_id: The employee_id of this Timesheet.  # noqa: E501
        :type: str
        """
        if employee_id is None:
            raise ValueError(
                "Invalid value for `employee_id`, must not be `None`"
            )  # noqa: E501

        self._employee_id = employee_id

    @property
    def start_date(self):
        """Gets the start_date of this Timesheet.  # noqa: E501

        Period start date (YYYY-MM-DD)  # noqa: E501

        :return: The start_date of this Timesheet.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Timesheet.

        Period start date (YYYY-MM-DD)  # noqa: E501

        :param start_date: The start_date of this Timesheet.  # noqa: E501
        :type: date
        """
        if start_date is None:
            raise ValueError(
                "Invalid value for `start_date`, must not be `None`"
            )  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Timesheet.  # noqa: E501

        Period end date (YYYY-MM-DD)  # noqa: E501

        :return: The end_date of this Timesheet.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Timesheet.

        Period end date (YYYY-MM-DD)  # noqa: E501

        :param end_date: The end_date of this Timesheet.  # noqa: E501
        :type: date
        """
        if end_date is None:
            raise ValueError(
                "Invalid value for `end_date`, must not be `None`"
            )  # noqa: E501

        self._end_date = end_date

    @property
    def status(self):
        """Gets the status of this Timesheet.  # noqa: E501


        :return: The status of this Timesheet.  # noqa: E501
        :rtype: TimesheetStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Timesheet.


        :param status: The status of this Timesheet.  # noqa: E501
        :type: TimesheetStatus
        """

        self._status = status

    @property
    def hours(self):
        """Gets the hours of this Timesheet.  # noqa: E501

        Timesheet total hours  # noqa: E501

        :return: The hours of this Timesheet.  # noqa: E501
        :rtype: float
        """
        return self._hours

    @hours.setter
    def hours(self, hours):
        """Sets the hours of this Timesheet.

        Timesheet total hours  # noqa: E501

        :param hours: The hours of this Timesheet.  # noqa: E501
        :type: float
        """

        self._hours = hours

    @property
    def timesheet_id(self):
        """Gets the timesheet_id of this Timesheet.  # noqa: E501

        The Xero identifier for a Payroll Timesheet  # noqa: E501

        :return: The timesheet_id of this Timesheet.  # noqa: E501
        :rtype: str
        """
        return self._timesheet_id

    @timesheet_id.setter
    def timesheet_id(self, timesheet_id):
        """Sets the timesheet_id of this Timesheet.

        The Xero identifier for a Payroll Timesheet  # noqa: E501

        :param timesheet_id: The timesheet_id of this Timesheet.  # noqa: E501
        :type: str
        """

        self._timesheet_id = timesheet_id

    @property
    def timesheet_lines(self):
        """Gets the timesheet_lines of this Timesheet.  # noqa: E501


        :return: The timesheet_lines of this Timesheet.  # noqa: E501
        :rtype: list[TimesheetLine]
        """
        return self._timesheet_lines

    @timesheet_lines.setter
    def timesheet_lines(self, timesheet_lines):
        """Sets the timesheet_lines of this Timesheet.


        :param timesheet_lines: The timesheet_lines of this Timesheet.  # noqa: E501
        :type: list[TimesheetLine]
        """

        self._timesheet_lines = timesheet_lines

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Timesheet.  # noqa: E501

        Last modified timestamp  # noqa: E501

        :return: The updated_date_utc of this Timesheet.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Timesheet.

        Last modified timestamp  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Timesheet.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def validation_errors(self):
        """Gets the validation_errors of this Timesheet.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this Timesheet.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this Timesheet.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this Timesheet.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ReportWithRow(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "report_id": "str",
        "report_name": "str",
        "report_title": "str",
        "report_type": "str",
        "report_titles": "list[str]",
        "report_date": "str",
        "rows": "list[ReportRows]",
        "updated_date_utc": "datetime[ms-format]",
        "fields": "list[ReportFields]",
    }

    attribute_map = {
        "report_id": "ReportID",
        "report_name": "ReportName",
        "report_title": "ReportTitle",
        "report_type": "ReportType",
        "report_titles": "ReportTitles",
        "report_date": "ReportDate",
        "rows": "Rows",
        "updated_date_utc": "UpdatedDateUTC",
        "fields": "Fields",
    }

    def __init__(
        self,
        report_id=None,
        report_name=None,
        report_title=None,
        report_type=None,
        report_titles=None,
        report_date=None,
        rows=None,
        updated_date_utc=None,
        fields=None,
    ):  # noqa: E501
        """ReportWithRow - a model defined in OpenAPI"""  # noqa: E501

        self._report_id = None
        self._report_name = None
        self._report_title = None
        self._report_type = None
        self._report_titles = None
        self._report_date = None
        self._rows = None
        self._updated_date_utc = None
        self._fields = None
        self.discriminator = None

        if report_id is not None:
            self.report_id = report_id
        if report_name is not None:
            self.report_name = report_name
        if report_title is not None:
            self.report_title = report_title
        if report_type is not None:
            self.report_type = report_type
        if report_titles is not None:
            self.report_titles = report_titles
        if report_date is not None:
            self.report_date = report_date
        if rows is not None:
            self.rows = rows
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if fields is not None:
            self.fields = fields

    @property
    def report_id(self):
        """Gets the report_id of this ReportWithRow.  # noqa: E501

        Report id  # noqa: E501

        :return: The report_id of this ReportWithRow.  # noqa: E501
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """Sets the report_id of this ReportWithRow.

        Report id  # noqa: E501

        :param report_id: The report_id of this ReportWithRow.  # noqa: E501
        :type: str
        """

        self._report_id = report_id

    @property
    def report_name(self):
        """Gets the report_name of this ReportWithRow.  # noqa: E501

        Name of the report  # noqa: E501

        :return: The report_name of this ReportWithRow.  # noqa: E501
        :rtype: str
        """
        return self._report_name

    @report_name.setter
    def report_name(self, report_name):
        """Sets the report_name of this ReportWithRow.

        Name of the report  # noqa: E501

        :param report_name: The report_name of this ReportWithRow.  # noqa: E501
        :type: str
        """

        self._report_name = report_name

    @property
    def report_title(self):
        """Gets the report_title of this ReportWithRow.  # noqa: E501

        Title of the report  # noqa: E501

        :return: The report_title of this ReportWithRow.  # noqa: E501
        :rtype: str
        """
        return self._report_title

    @report_title.setter
    def report_title(self, report_title):
        """Sets the report_title of this ReportWithRow.

        Title of the report  # noqa: E501

        :param report_title: The report_title of this ReportWithRow.  # noqa: E501
        :type: str
        """

        self._report_title = report_title

    @property
    def report_type(self):
        """Gets the report_type of this ReportWithRow.  # noqa: E501

        The type of report (BalanceSheet,ProfitLoss, etc)  # noqa: E501

        :return: The report_type of this ReportWithRow.  # noqa: E501
        :rtype: str
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this ReportWithRow.

        The type of report (BalanceSheet,ProfitLoss, etc)  # noqa: E501

        :param report_type: The report_type of this ReportWithRow.  # noqa: E501
        :type: str
        """

        self._report_type = report_type

    @property
    def report_titles(self):
        """Gets the report_titles of this ReportWithRow.  # noqa: E501

        Report titles array (3 to 4 strings with the report name, orgnisation name and time frame of report)  # noqa: E501

        :return: The report_titles of this ReportWithRow.  # noqa: E501
        :rtype: list[str]
        """
        return self._report_titles

    @report_titles.setter
    def report_titles(self, report_titles):
        """Sets the report_titles of this ReportWithRow.

        Report titles array (3 to 4 strings with the report name, orgnisation name and time frame of report)  # noqa: E501

        :param report_titles: The report_titles of this ReportWithRow.  # noqa: E501
        :type: list[str]
        """

        self._report_titles = report_titles

    @property
    def report_date(self):
        """Gets the report_date of this ReportWithRow.  # noqa: E501

        Date of report  # noqa: E501

        :return: The report_date of this ReportWithRow.  # noqa: E501
        :rtype: str
        """
        return self._report_date

    @report_date.setter
    def report_date(self, report_date):
        """Sets the report_date of this ReportWithRow.

        Date of report  # noqa: E501

        :param report_date: The report_date of this ReportWithRow.  # noqa: E501
        :type: str
        """

        self._report_date = report_date

    @property
    def rows(self):
        """Gets the rows of this ReportWithRow.  # noqa: E501


        :return: The rows of this ReportWithRow.  # noqa: E501
        :rtype: list[ReportRows]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """Sets the rows of this ReportWithRow.


        :param rows: The rows of this ReportWithRow.  # noqa: E501
        :type: list[ReportRows]
        """

        self._rows = rows

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this ReportWithRow.  # noqa: E501

        Updated Date  # noqa: E501

        :return: The updated_date_utc of this ReportWithRow.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this ReportWithRow.

        Updated Date  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this ReportWithRow.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def fields(self):
        """Gets the fields of this ReportWithRow.  # noqa: E501


        :return: The fields of this ReportWithRow.  # noqa: E501
        :rtype: list[ReportFields]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this ReportWithRow.


        :param fields: The fields of this ReportWithRow.  # noqa: E501
        :type: list[ReportFields]
        """

        self._fields = fields



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EmployeeStatutoryLeaveSummary(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "statutory_leave_id": "str",
        "employee_id": "str",
        "type": "str",
        "start_date": "date",
        "end_date": "date",
        "is_entitled": "bool",
        "status": "str",
    }

    attribute_map = {
        "statutory_leave_id": "statutoryLeaveID",
        "employee_id": "employeeID",
        "type": "type",
        "start_date": "startDate",
        "end_date": "endDate",
        "is_entitled": "isEntitled",
        "status": "status",
    }

    def __init__(
        self,
        statutory_leave_id=None,
        employee_id=None,
        type=None,
        start_date=None,
        end_date=None,
        is_entitled=None,
        status=None,
    ):  # noqa: E501
        """EmployeeStatutoryLeaveSummary - a model defined in OpenAPI"""  # noqa: E501

        self._statutory_leave_id = None
        self._employee_id = None
        self._type = None
        self._start_date = None
        self._end_date = None
        self._is_entitled = None
        self._status = None
        self.discriminator = None

        if statutory_leave_id is not None:
            self.statutory_leave_id = statutory_leave_id
        if employee_id is not None:
            self.employee_id = employee_id
        if type is not None:
            self.type = type
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if is_entitled is not None:
            self.is_entitled = is_entitled
        if status is not None:
            self.status = status

    @property
    def statutory_leave_id(self):
        """Gets the statutory_leave_id of this EmployeeStatutoryLeaveSummary.  # noqa: E501

        The unique identifier (guid) of a statutory leave.  # noqa: E501

        :return: The statutory_leave_id of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :rtype: str
        """
        return self._statutory_leave_id

    @statutory_leave_id.setter
    def statutory_leave_id(self, statutory_leave_id):
        """Sets the statutory_leave_id of this EmployeeStatutoryLeaveSummary.

        The unique identifier (guid) of a statutory leave.  # noqa: E501

        :param statutory_leave_id: The statutory_leave_id of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :type: str
        """

        self._statutory_leave_id = statutory_leave_id

    @property
    def employee_id(self):
        """Gets the employee_id of this EmployeeStatutoryLeaveSummary.  # noqa: E501

        The unique identifier (guid) of the employee  # noqa: E501

        :return: The employee_id of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this EmployeeStatutoryLeaveSummary.

        The unique identifier (guid) of the employee  # noqa: E501

        :param employee_id: The employee_id of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def type(self):
        """Gets the type of this EmployeeStatutoryLeaveSummary.  # noqa: E501

        The category of statutory leave  # noqa: E501

        :return: The type of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EmployeeStatutoryLeaveSummary.

        The category of statutory leave  # noqa: E501

        :param type: The type of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "Sick",
            "Adoption",
            "Maternity",
            "Paternity",
            "Sharedparental",
            "None",
        ]  # noqa: E501

        if type:
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                        type, allowed_values
                    )
                )

        self._type = type

    @property
    def start_date(self):
        """Gets the start_date of this EmployeeStatutoryLeaveSummary.  # noqa: E501

        The date when the leave starts  # noqa: E501

        :return: The start_date of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this EmployeeStatutoryLeaveSummary.

        The date when the leave starts  # noqa: E501

        :param start_date: The start_date of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this EmployeeStatutoryLeaveSummary.  # noqa: E501

        The date when the leave ends  # noqa: E501

        :return: The end_date of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this EmployeeStatutoryLeaveSummary.

        The date when the leave ends  # noqa: E501

        :param end_date: The end_date of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def is_entitled(self):
        """Gets the is_entitled of this EmployeeStatutoryLeaveSummary.  # noqa: E501

        Whether the leave was entitled to receive payment  # noqa: E501

        :return: The is_entitled of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :rtype: bool
        """
        return self._is_entitled

    @is_entitled.setter
    def is_entitled(self, is_entitled):
        """Sets the is_entitled of this EmployeeStatutoryLeaveSummary.

        Whether the leave was entitled to receive payment  # noqa: E501

        :param is_entitled: The is_entitled of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :type: bool
        """

        self._is_entitled = is_entitled

    @property
    def status(self):
        """Gets the status of this EmployeeStatutoryLeaveSummary.  # noqa: E501

        The status of the leave  # noqa: E501

        :return: The status of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this EmployeeStatutoryLeaveSummary.

        The status of the leave  # noqa: E501

        :param status: The status of this EmployeeStatutoryLeaveSummary.  # noqa: E501
        :type: str
        """
        allowed_values = ["Pending", "In-Progress", "Completed", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Error(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"message": "str", "model_state": "object"}

    attribute_map = {"message": "message", "model_state": "modelState"}

    def __init__(self, message=None, model_state=None):  # noqa: E501
        """Error - a model defined in OpenAPI"""  # noqa: E501

        self._message = None
        self._model_state = None
        self.discriminator = None

        if message is not None:
            self.message = message
        if model_state is not None:
            self.model_state = model_state

    @property
    def message(self):
        """Gets the message of this Error.  # noqa: E501

        Exception message  # noqa: E501

        :return: The message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Error.

        Exception message  # noqa: E501

        :param message: The message of this Error.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def model_state(self):
        """Gets the model_state of this Error.  # noqa: E501

        Array of Elements of validation Errors  # noqa: E501

        :return: The model_state of this Error.  # noqa: E501
        :rtype: object
        """
        return self._model_state

    @model_state.setter
    def model_state(self, model_state):
        """Sets the model_state of this Error.

        Array of Elements of validation Errors  # noqa: E501

        :param model_state: The model_state of this Error.  # noqa: E501
        :type: object
        """

        self._model_state = model_state



# coding: utf-8

"""
    Xero Assets API

    The Assets API exposes fixed asset related functions of the Xero Accounting application and can be used for a variety of purposes such as creating assets, retrieving asset valuations etc.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Error(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "resource_validation_errors": "list[ResourceValidationErrorsElement]",
        "field_validation_errors": "list[FieldValidationErrorsElement]",
        "type": "str",
        "title": "str",
        "detail": "str",
    }

    attribute_map = {
        "resource_validation_errors": "resourceValidationErrors",
        "field_validation_errors": "fieldValidationErrors",
        "type": "type",
        "title": "title",
        "detail": "detail",
    }

    def __init__(
        self,
        resource_validation_errors=None,
        field_validation_errors=None,
        type=None,
        title=None,
        detail=None,
    ):  # noqa: E501
        """Error - a model defined in OpenAPI"""  # noqa: E501

        self._resource_validation_errors = None
        self._field_validation_errors = None
        self._type = None
        self._title = None
        self._detail = None
        self.discriminator = None

        if resource_validation_errors is not None:
            self.resource_validation_errors = resource_validation_errors
        if field_validation_errors is not None:
            self.field_validation_errors = field_validation_errors
        if type is not None:
            self.type = type
        if title is not None:
            self.title = title
        if detail is not None:
            self.detail = detail

    @property
    def resource_validation_errors(self):
        """Gets the resource_validation_errors of this Error.  # noqa: E501

        Array of elements of resource validation errors  # noqa: E501

        :return: The resource_validation_errors of this Error.  # noqa: E501
        :rtype: list[ResourceValidationErrorsElement]
        """
        return self._resource_validation_errors

    @resource_validation_errors.setter
    def resource_validation_errors(self, resource_validation_errors):
        """Sets the resource_validation_errors of this Error.

        Array of elements of resource validation errors  # noqa: E501

        :param resource_validation_errors: The resource_validation_errors of this Error.  # noqa: E501
        :type: list[ResourceValidationErrorsElement]
        """

        self._resource_validation_errors = resource_validation_errors

    @property
    def field_validation_errors(self):
        """Gets the field_validation_errors of this Error.  # noqa: E501

        Array of elements of field validation errors  # noqa: E501

        :return: The field_validation_errors of this Error.  # noqa: E501
        :rtype: list[FieldValidationErrorsElement]
        """
        return self._field_validation_errors

    @field_validation_errors.setter
    def field_validation_errors(self, field_validation_errors):
        """Sets the field_validation_errors of this Error.

        Array of elements of field validation errors  # noqa: E501

        :param field_validation_errors: The field_validation_errors of this Error.  # noqa: E501
        :type: list[FieldValidationErrorsElement]
        """

        self._field_validation_errors = field_validation_errors

    @property
    def type(self):
        """Gets the type of this Error.  # noqa: E501

        The internal type of error, not accessible externally  # noqa: E501

        :return: The type of this Error.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Error.

        The internal type of error, not accessible externally  # noqa: E501

        :param type: The type of this Error.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def title(self):
        """Gets the title of this Error.  # noqa: E501

        Title of the error  # noqa: E501

        :return: The title of this Error.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Error.

        Title of the error  # noqa: E501

        :param title: The title of this Error.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def detail(self):
        """Gets the detail of this Error.  # noqa: E501

        Detail of the error  # noqa: E501

        :return: The detail of this Error.  # noqa: E501
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this Error.

        Detail of the error  # noqa: E501

        :param detail: The detail of this Error.  # noqa: E501
        :type: str
        """

        self._detail = detail



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class DeductionLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "deduction_type_id": "str",
        "calculation_type": "DeductionTypeCalculationType",
        "amount": "float",
        "percentage": "float",
        "number_of_units": "float",
    }

    attribute_map = {
        "deduction_type_id": "DeductionTypeID",
        "calculation_type": "CalculationType",
        "amount": "Amount",
        "percentage": "Percentage",
        "number_of_units": "NumberOfUnits",
    }

    def __init__(
        self,
        deduction_type_id=None,
        calculation_type=None,
        amount=None,
        percentage=None,
        number_of_units=None,
    ):  # noqa: E501
        """DeductionLine - a model defined in OpenAPI"""  # noqa: E501

        self._deduction_type_id = None
        self._calculation_type = None
        self._amount = None
        self._percentage = None
        self._number_of_units = None
        self.discriminator = None

        self.deduction_type_id = deduction_type_id
        self.calculation_type = calculation_type
        if amount is not None:
            self.amount = amount
        if percentage is not None:
            self.percentage = percentage
        if number_of_units is not None:
            self.number_of_units = number_of_units

    @property
    def deduction_type_id(self):
        """Gets the deduction_type_id of this DeductionLine.  # noqa: E501

        Xero deduction type identifier  # noqa: E501

        :return: The deduction_type_id of this DeductionLine.  # noqa: E501
        :rtype: str
        """
        return self._deduction_type_id

    @deduction_type_id.setter
    def deduction_type_id(self, deduction_type_id):
        """Sets the deduction_type_id of this DeductionLine.

        Xero deduction type identifier  # noqa: E501

        :param deduction_type_id: The deduction_type_id of this DeductionLine.  # noqa: E501
        :type: str
        """
        if deduction_type_id is None:
            raise ValueError(
                "Invalid value for `deduction_type_id`, must not be `None`"
            )  # noqa: E501

        self._deduction_type_id = deduction_type_id

    @property
    def calculation_type(self):
        """Gets the calculation_type of this DeductionLine.  # noqa: E501


        :return: The calculation_type of this DeductionLine.  # noqa: E501
        :rtype: DeductionTypeCalculationType
        """
        return self._calculation_type

    @calculation_type.setter
    def calculation_type(self, calculation_type):
        """Sets the calculation_type of this DeductionLine.


        :param calculation_type: The calculation_type of this DeductionLine.  # noqa: E501
        :type: DeductionTypeCalculationType
        """
        if calculation_type is None:
            raise ValueError(
                "Invalid value for `calculation_type`, must not be `None`"
            )  # noqa: E501

        self._calculation_type = calculation_type

    @property
    def amount(self):
        """Gets the amount of this DeductionLine.  # noqa: E501

        Deduction type amount  # noqa: E501

        :return: The amount of this DeductionLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this DeductionLine.

        Deduction type amount  # noqa: E501

        :param amount: The amount of this DeductionLine.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def percentage(self):
        """Gets the percentage of this DeductionLine.  # noqa: E501

        The Percentage of the Deduction  # noqa: E501

        :return: The percentage of this DeductionLine.  # noqa: E501
        :rtype: float
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """Sets the percentage of this DeductionLine.

        The Percentage of the Deduction  # noqa: E501

        :param percentage: The percentage of this DeductionLine.  # noqa: E501
        :type: float
        """

        self._percentage = percentage

    @property
    def number_of_units(self):
        """Gets the number_of_units of this DeductionLine.  # noqa: E501

        Deduction number of units  # noqa: E501

        :return: The number_of_units of this DeductionLine.  # noqa: E501
        :rtype: float
        """
        return self._number_of_units

    @number_of_units.setter
    def number_of_units(self, number_of_units):
        """Sets the number_of_units of this DeductionLine.

        Deduction number of units  # noqa: E501

        :param number_of_units: The number_of_units of this DeductionLine.  # noqa: E501
        :type: float
        """

        self._number_of_units = number_of_units



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ReimbursementLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "reimbursement_type_id": "str",
        "description": "str",
        "amount": "float",
        "rate_per_unit": "float",
        "number_of_units": "float",
    }

    attribute_map = {
        "reimbursement_type_id": "reimbursementTypeID",
        "description": "description",
        "amount": "amount",
        "rate_per_unit": "ratePerUnit",
        "number_of_units": "numberOfUnits",
    }

    def __init__(
        self,
        reimbursement_type_id=None,
        description=None,
        amount=None,
        rate_per_unit=None,
        number_of_units=None,
    ):  # noqa: E501
        """ReimbursementLine - a model defined in OpenAPI"""  # noqa: E501

        self._reimbursement_type_id = None
        self._description = None
        self._amount = None
        self._rate_per_unit = None
        self._number_of_units = None
        self.discriminator = None

        if reimbursement_type_id is not None:
            self.reimbursement_type_id = reimbursement_type_id
        if description is not None:
            self.description = description
        if amount is not None:
            self.amount = amount
        if rate_per_unit is not None:
            self.rate_per_unit = rate_per_unit
        if number_of_units is not None:
            self.number_of_units = number_of_units

    @property
    def reimbursement_type_id(self):
        """Gets the reimbursement_type_id of this ReimbursementLine.  # noqa: E501

        Xero identifier for payroll reimbursement  # noqa: E501

        :return: The reimbursement_type_id of this ReimbursementLine.  # noqa: E501
        :rtype: str
        """
        return self._reimbursement_type_id

    @reimbursement_type_id.setter
    def reimbursement_type_id(self, reimbursement_type_id):
        """Sets the reimbursement_type_id of this ReimbursementLine.

        Xero identifier for payroll reimbursement  # noqa: E501

        :param reimbursement_type_id: The reimbursement_type_id of this ReimbursementLine.  # noqa: E501
        :type: str
        """

        self._reimbursement_type_id = reimbursement_type_id

    @property
    def description(self):
        """Gets the description of this ReimbursementLine.  # noqa: E501

        Reimbursement line description  # noqa: E501

        :return: The description of this ReimbursementLine.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ReimbursementLine.

        Reimbursement line description  # noqa: E501

        :param description: The description of this ReimbursementLine.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def amount(self):
        """Gets the amount of this ReimbursementLine.  # noqa: E501

        Reimbursement amount  # noqa: E501

        :return: The amount of this ReimbursementLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this ReimbursementLine.

        Reimbursement amount  # noqa: E501

        :param amount: The amount of this ReimbursementLine.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def rate_per_unit(self):
        """Gets the rate_per_unit of this ReimbursementLine.  # noqa: E501

        Rate per unit for leave earnings line  # noqa: E501

        :return: The rate_per_unit of this ReimbursementLine.  # noqa: E501
        :rtype: float
        """
        return self._rate_per_unit

    @rate_per_unit.setter
    def rate_per_unit(self, rate_per_unit):
        """Sets the rate_per_unit of this ReimbursementLine.

        Rate per unit for leave earnings line  # noqa: E501

        :param rate_per_unit: The rate_per_unit of this ReimbursementLine.  # noqa: E501
        :type: float
        """

        self._rate_per_unit = rate_per_unit

    @property
    def number_of_units(self):
        """Gets the number_of_units of this ReimbursementLine.  # noqa: E501

        Leave earnings number of units  # noqa: E501

        :return: The number_of_units of this ReimbursementLine.  # noqa: E501
        :rtype: float
        """
        return self._number_of_units

    @number_of_units.setter
    def number_of_units(self, number_of_units):
        """Sets the number_of_units of this ReimbursementLine.

        Leave earnings number of units  # noqa: E501

        :param number_of_units: The number_of_units of this ReimbursementLine.  # noqa: E501
        :type: float
        """

        self._number_of_units = number_of_units



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Contact(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "contact_id": "str",
        "contact_number": "str",
        "account_number": "str",
        "contact_status": "str",
        "name": "str",
        "first_name": "str",
        "last_name": "str",
        "email_address": "str",
        "skype_user_name": "str",
        "contact_persons": "list[ContactPerson]",
        "bank_account_details": "str",
        "tax_number": "str",
        "accounts_receivable_tax_type": "str",
        "accounts_payable_tax_type": "str",
        "addresses": "list[Address]",
        "phones": "list[Phone]",
        "is_supplier": "bool",
        "is_customer": "bool",
        "default_currency": "CurrencyCode",
        "xero_network_key": "str",
        "sales_default_account_code": "str",
        "purchases_default_account_code": "str",
        "sales_tracking_categories": "list[SalesTrackingCategory]",
        "purchases_tracking_categories": "list[SalesTrackingCategory]",
        "tracking_category_name": "str",
        "tracking_category_option": "str",
        "payment_terms": "PaymentTerm",
        "updated_date_utc": "datetime[ms-format]",
        "contact_groups": "list[ContactGroup]",
        "website": "str",
        "branding_theme": "BrandingTheme",
        "batch_payments": "BatchPaymentDetails",
        "discount": "float",
        "balances": "Balances",
        "attachments": "list[Attachment]",
        "has_attachments": "bool",
        "validation_errors": "list[ValidationError]",
        "has_validation_errors": "bool",
        "status_attribute_string": "str",
    }

    attribute_map = {
        "contact_id": "ContactID",
        "contact_number": "ContactNumber",
        "account_number": "AccountNumber",
        "contact_status": "ContactStatus",
        "name": "Name",
        "first_name": "FirstName",
        "last_name": "LastName",
        "email_address": "EmailAddress",
        "skype_user_name": "SkypeUserName",
        "contact_persons": "ContactPersons",
        "bank_account_details": "BankAccountDetails",
        "tax_number": "TaxNumber",
        "accounts_receivable_tax_type": "AccountsReceivableTaxType",
        "accounts_payable_tax_type": "AccountsPayableTaxType",
        "addresses": "Addresses",
        "phones": "Phones",
        "is_supplier": "IsSupplier",
        "is_customer": "IsCustomer",
        "default_currency": "DefaultCurrency",
        "xero_network_key": "XeroNetworkKey",
        "sales_default_account_code": "SalesDefaultAccountCode",
        "purchases_default_account_code": "PurchasesDefaultAccountCode",
        "sales_tracking_categories": "SalesTrackingCategories",
        "purchases_tracking_categories": "PurchasesTrackingCategories",
        "tracking_category_name": "TrackingCategoryName",
        "tracking_category_option": "TrackingCategoryOption",
        "payment_terms": "PaymentTerms",
        "updated_date_utc": "UpdatedDateUTC",
        "contact_groups": "ContactGroups",
        "website": "Website",
        "branding_theme": "BrandingTheme",
        "batch_payments": "BatchPayments",
        "discount": "Discount",
        "balances": "Balances",
        "attachments": "Attachments",
        "has_attachments": "HasAttachments",
        "validation_errors": "ValidationErrors",
        "has_validation_errors": "HasValidationErrors",
        "status_attribute_string": "StatusAttributeString",
    }

    def __init__(
        self,
        contact_id=None,
        contact_number=None,
        account_number=None,
        contact_status=None,
        name=None,
        first_name=None,
        last_name=None,
        email_address=None,
        skype_user_name=None,
        contact_persons=None,
        bank_account_details=None,
        tax_number=None,
        accounts_receivable_tax_type=None,
        accounts_payable_tax_type=None,
        addresses=None,
        phones=None,
        is_supplier=None,
        is_customer=None,
        default_currency=None,
        xero_network_key=None,
        sales_default_account_code=None,
        purchases_default_account_code=None,
        sales_tracking_categories=None,
        purchases_tracking_categories=None,
        tracking_category_name=None,
        tracking_category_option=None,
        payment_terms=None,
        updated_date_utc=None,
        contact_groups=None,
        website=None,
        branding_theme=None,
        batch_payments=None,
        discount=None,
        balances=None,
        attachments=None,
        has_attachments=False,
        validation_errors=None,
        has_validation_errors=False,
        status_attribute_string=None,
    ):  # noqa: E501
        """Contact - a model defined in OpenAPI"""  # noqa: E501

        self._contact_id = None
        self._contact_number = None
        self._account_number = None
        self._contact_status = None
        self._name = None
        self._first_name = None
        self._last_name = None
        self._email_address = None
        self._skype_user_name = None
        self._contact_persons = None
        self._bank_account_details = None
        self._tax_number = None
        self._accounts_receivable_tax_type = None
        self._accounts_payable_tax_type = None
        self._addresses = None
        self._phones = None
        self._is_supplier = None
        self._is_customer = None
        self._default_currency = None
        self._xero_network_key = None
        self._sales_default_account_code = None
        self._purchases_default_account_code = None
        self._sales_tracking_categories = None
        self._purchases_tracking_categories = None
        self._tracking_category_name = None
        self._tracking_category_option = None
        self._payment_terms = None
        self._updated_date_utc = None
        self._contact_groups = None
        self._website = None
        self._branding_theme = None
        self._batch_payments = None
        self._discount = None
        self._balances = None
        self._attachments = None
        self._has_attachments = None
        self._validation_errors = None
        self._has_validation_errors = None
        self._status_attribute_string = None
        self.discriminator = None

        if contact_id is not None:
            self.contact_id = contact_id
        if contact_number is not None:
            self.contact_number = contact_number
        if account_number is not None:
            self.account_number = account_number
        if contact_status is not None:
            self.contact_status = contact_status
        if name is not None:
            self.name = name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email_address is not None:
            self.email_address = email_address
        if skype_user_name is not None:
            self.skype_user_name = skype_user_name
        if contact_persons is not None:
            self.contact_persons = contact_persons
        if bank_account_details is not None:
            self.bank_account_details = bank_account_details
        if tax_number is not None:
            self.tax_number = tax_number
        if accounts_receivable_tax_type is not None:
            self.accounts_receivable_tax_type = accounts_receivable_tax_type
        if accounts_payable_tax_type is not None:
            self.accounts_payable_tax_type = accounts_payable_tax_type
        if addresses is not None:
            self.addresses = addresses
        if phones is not None:
            self.phones = phones
        if is_supplier is not None:
            self.is_supplier = is_supplier
        if is_customer is not None:
            self.is_customer = is_customer
        if default_currency is not None:
            self.default_currency = default_currency
        if xero_network_key is not None:
            self.xero_network_key = xero_network_key
        if sales_default_account_code is not None:
            self.sales_default_account_code = sales_default_account_code
        if purchases_default_account_code is not None:
            self.purchases_default_account_code = purchases_default_account_code
        if sales_tracking_categories is not None:
            self.sales_tracking_categories = sales_tracking_categories
        if purchases_tracking_categories is not None:
            self.purchases_tracking_categories = purchases_tracking_categories
        if tracking_category_name is not None:
            self.tracking_category_name = tracking_category_name
        if tracking_category_option is not None:
            self.tracking_category_option = tracking_category_option
        if payment_terms is not None:
            self.payment_terms = payment_terms
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if contact_groups is not None:
            self.contact_groups = contact_groups
        if website is not None:
            self.website = website
        if branding_theme is not None:
            self.branding_theme = branding_theme
        if batch_payments is not None:
            self.batch_payments = batch_payments
        if discount is not None:
            self.discount = discount
        if balances is not None:
            self.balances = balances
        if attachments is not None:
            self.attachments = attachments
        if has_attachments is not None:
            self.has_attachments = has_attachments
        if validation_errors is not None:
            self.validation_errors = validation_errors
        if has_validation_errors is not None:
            self.has_validation_errors = has_validation_errors
        if status_attribute_string is not None:
            self.status_attribute_string = status_attribute_string

    @property
    def contact_id(self):
        """Gets the contact_id of this Contact.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The contact_id of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._contact_id

    @contact_id.setter
    def contact_id(self, contact_id):
        """Sets the contact_id of this Contact.

        Xero identifier  # noqa: E501

        :param contact_id: The contact_id of this Contact.  # noqa: E501
        :type: str
        """

        self._contact_id = contact_id

    @property
    def contact_number(self):
        """Gets the contact_number of this Contact.  # noqa: E501

        This can be updated via the API only i.e. This field is read only on the Xero contact screen, used to identify contacts in external systems (max length = 50). If the Contact Number is used, this is displayed as Contact Code in the Contacts UI in Xero.  # noqa: E501

        :return: The contact_number of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._contact_number

    @contact_number.setter
    def contact_number(self, contact_number):
        """Sets the contact_number of this Contact.

        This can be updated via the API only i.e. This field is read only on the Xero contact screen, used to identify contacts in external systems (max length = 50). If the Contact Number is used, this is displayed as Contact Code in the Contacts UI in Xero.  # noqa: E501

        :param contact_number: The contact_number of this Contact.  # noqa: E501
        :type: str
        """
        if contact_number is not None and len(contact_number) > 50:
            raise ValueError(
                "Invalid value for `contact_number`, "
                "length must be less than or equal to `50`"
            )  # noqa: E501

        self._contact_number = contact_number

    @property
    def account_number(self):
        """Gets the account_number of this Contact.  # noqa: E501

        A user defined account number. This can be updated via the API and the Xero UI (max length = 50)  # noqa: E501

        :return: The account_number of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this Contact.

        A user defined account number. This can be updated via the API and the Xero UI (max length = 50)  # noqa: E501

        :param account_number: The account_number of this Contact.  # noqa: E501
        :type: str
        """
        if account_number is not None and len(account_number) > 50:
            raise ValueError(
                "Invalid value for `account_number`, "
                "length must be less than or equal to `50`"
            )  # noqa: E501

        self._account_number = account_number

    @property
    def contact_status(self):
        """Gets the contact_status of this Contact.  # noqa: E501

        Current status of a contact – see contact status types  # noqa: E501

        :return: The contact_status of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._contact_status

    @contact_status.setter
    def contact_status(self, contact_status):
        """Sets the contact_status of this Contact.

        Current status of a contact – see contact status types  # noqa: E501

        :param contact_status: The contact_status of this Contact.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "ARCHIVED", "GDPRREQUEST", "None"]  # noqa: E501

        if contact_status:
            if contact_status not in allowed_values:
                raise ValueError(
                    "Invalid value for `contact_status` ({0}), must be one of {1}".format(  # noqa: E501
                        contact_status, allowed_values
                    )
                )

        self._contact_status = contact_status

    @property
    def name(self):
        """Gets the name of this Contact.  # noqa: E501

        Full name of contact/organisation (max length = 255)  # noqa: E501

        :return: The name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Contact.

        Full name of contact/organisation (max length = 255)  # noqa: E501

        :param name: The name of this Contact.  # noqa: E501
        :type: str
        """
        if name is not None and len(name) > 255:
            raise ValueError(
                "Invalid value for `name`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._name = name

    @property
    def first_name(self):
        """Gets the first_name of this Contact.  # noqa: E501

        First name of contact person (max length = 255)  # noqa: E501

        :return: The first_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Contact.

        First name of contact person (max length = 255)  # noqa: E501

        :param first_name: The first_name of this Contact.  # noqa: E501
        :type: str
        """
        if first_name is not None and len(first_name) > 255:
            raise ValueError(
                "Invalid value for `first_name`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this Contact.  # noqa: E501

        Last name of contact person (max length = 255)  # noqa: E501

        :return: The last_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Contact.

        Last name of contact person (max length = 255)  # noqa: E501

        :param last_name: The last_name of this Contact.  # noqa: E501
        :type: str
        """
        if last_name is not None and len(last_name) > 255:
            raise ValueError(
                "Invalid value for `last_name`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._last_name = last_name

    @property
    def email_address(self):
        """Gets the email_address of this Contact.  # noqa: E501

        Email address of contact person (umlauts not supported) (max length  = 255)  # noqa: E501

        :return: The email_address of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this Contact.

        Email address of contact person (umlauts not supported) (max length  = 255)  # noqa: E501

        :param email_address: The email_address of this Contact.  # noqa: E501
        :type: str
        """
        if email_address is not None and len(email_address) > 255:
            raise ValueError(
                "Invalid value for `email_address`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._email_address = email_address

    @property
    def skype_user_name(self):
        """Gets the skype_user_name of this Contact.  # noqa: E501

        Skype user name of contact  # noqa: E501

        :return: The skype_user_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._skype_user_name

    @skype_user_name.setter
    def skype_user_name(self, skype_user_name):
        """Sets the skype_user_name of this Contact.

        Skype user name of contact  # noqa: E501

        :param skype_user_name: The skype_user_name of this Contact.  # noqa: E501
        :type: str
        """

        self._skype_user_name = skype_user_name

    @property
    def contact_persons(self):
        """Gets the contact_persons of this Contact.  # noqa: E501

        See contact persons  # noqa: E501

        :return: The contact_persons of this Contact.  # noqa: E501
        :rtype: list[ContactPerson]
        """
        return self._contact_persons

    @contact_persons.setter
    def contact_persons(self, contact_persons):
        """Sets the contact_persons of this Contact.

        See contact persons  # noqa: E501

        :param contact_persons: The contact_persons of this Contact.  # noqa: E501
        :type: list[ContactPerson]
        """

        self._contact_persons = contact_persons

    @property
    def bank_account_details(self):
        """Gets the bank_account_details of this Contact.  # noqa: E501

        Bank account number of contact  # noqa: E501

        :return: The bank_account_details of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._bank_account_details

    @bank_account_details.setter
    def bank_account_details(self, bank_account_details):
        """Sets the bank_account_details of this Contact.

        Bank account number of contact  # noqa: E501

        :param bank_account_details: The bank_account_details of this Contact.  # noqa: E501
        :type: str
        """

        self._bank_account_details = bank_account_details

    @property
    def tax_number(self):
        """Gets the tax_number of this Contact.  # noqa: E501

        Tax number of contact – this is also known as the ABN (Australia), GST Number (New Zealand), VAT Number (UK) or Tax ID Number (US and global) in the Xero UI depending on which regionalized version of Xero you are using (max length = 50)  # noqa: E501

        :return: The tax_number of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._tax_number

    @tax_number.setter
    def tax_number(self, tax_number):
        """Sets the tax_number of this Contact.

        Tax number of contact – this is also known as the ABN (Australia), GST Number (New Zealand), VAT Number (UK) or Tax ID Number (US and global) in the Xero UI depending on which regionalized version of Xero you are using (max length = 50)  # noqa: E501

        :param tax_number: The tax_number of this Contact.  # noqa: E501
        :type: str
        """
        if tax_number is not None and len(tax_number) > 50:
            raise ValueError(
                "Invalid value for `tax_number`, "
                "length must be less than or equal to `50`"
            )  # noqa: E501

        self._tax_number = tax_number

    @property
    def accounts_receivable_tax_type(self):
        """Gets the accounts_receivable_tax_type of this Contact.  # noqa: E501

        The tax type from TaxRates  # noqa: E501

        :return: The accounts_receivable_tax_type of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._accounts_receivable_tax_type

    @accounts_receivable_tax_type.setter
    def accounts_receivable_tax_type(self, accounts_receivable_tax_type):
        """Sets the accounts_receivable_tax_type of this Contact.

        The tax type from TaxRates  # noqa: E501

        :param accounts_receivable_tax_type: The accounts_receivable_tax_type of this Contact.  # noqa: E501
        :type: str
        """

        self._accounts_receivable_tax_type = accounts_receivable_tax_type

    @property
    def accounts_payable_tax_type(self):
        """Gets the accounts_payable_tax_type of this Contact.  # noqa: E501

        The tax type from TaxRates  # noqa: E501

        :return: The accounts_payable_tax_type of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._accounts_payable_tax_type

    @accounts_payable_tax_type.setter
    def accounts_payable_tax_type(self, accounts_payable_tax_type):
        """Sets the accounts_payable_tax_type of this Contact.

        The tax type from TaxRates  # noqa: E501

        :param accounts_payable_tax_type: The accounts_payable_tax_type of this Contact.  # noqa: E501
        :type: str
        """

        self._accounts_payable_tax_type = accounts_payable_tax_type

    @property
    def addresses(self):
        """Gets the addresses of this Contact.  # noqa: E501

        Store certain address types for a contact – see address types  # noqa: E501

        :return: The addresses of this Contact.  # noqa: E501
        :rtype: list[Address]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this Contact.

        Store certain address types for a contact – see address types  # noqa: E501

        :param addresses: The addresses of this Contact.  # noqa: E501
        :type: list[Address]
        """

        self._addresses = addresses

    @property
    def phones(self):
        """Gets the phones of this Contact.  # noqa: E501

        Store certain phone types for a contact – see phone types  # noqa: E501

        :return: The phones of this Contact.  # noqa: E501
        :rtype: list[Phone]
        """
        return self._phones

    @phones.setter
    def phones(self, phones):
        """Sets the phones of this Contact.

        Store certain phone types for a contact – see phone types  # noqa: E501

        :param phones: The phones of this Contact.  # noqa: E501
        :type: list[Phone]
        """

        self._phones = phones

    @property
    def is_supplier(self):
        """Gets the is_supplier of this Contact.  # noqa: E501

        true or false – Boolean that describes if a contact that has any AP  invoices entered against them. Cannot be set via PUT or POST – it is automatically set when an accounts payable invoice is generated against this contact.  # noqa: E501

        :return: The is_supplier of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._is_supplier

    @is_supplier.setter
    def is_supplier(self, is_supplier):
        """Sets the is_supplier of this Contact.

        true or false – Boolean that describes if a contact that has any AP  invoices entered against them. Cannot be set via PUT or POST – it is automatically set when an accounts payable invoice is generated against this contact.  # noqa: E501

        :param is_supplier: The is_supplier of this Contact.  # noqa: E501
        :type: bool
        """

        self._is_supplier = is_supplier

    @property
    def is_customer(self):
        """Gets the is_customer of this Contact.  # noqa: E501

        true or false – Boolean that describes if a contact has any AR invoices entered against them. Cannot be set via PUT or POST – it is automatically set when an accounts receivable invoice is generated against this contact.  # noqa: E501

        :return: The is_customer of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._is_customer

    @is_customer.setter
    def is_customer(self, is_customer):
        """Sets the is_customer of this Contact.

        true or false – Boolean that describes if a contact has any AR invoices entered against them. Cannot be set via PUT or POST – it is automatically set when an accounts receivable invoice is generated against this contact.  # noqa: E501

        :param is_customer: The is_customer of this Contact.  # noqa: E501
        :type: bool
        """

        self._is_customer = is_customer

    @property
    def default_currency(self):
        """Gets the default_currency of this Contact.  # noqa: E501


        :return: The default_currency of this Contact.  # noqa: E501
        :rtype: CurrencyCode
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this Contact.


        :param default_currency: The default_currency of this Contact.  # noqa: E501
        :type: CurrencyCode
        """

        self._default_currency = default_currency

    @property
    def xero_network_key(self):
        """Gets the xero_network_key of this Contact.  # noqa: E501

        Store XeroNetworkKey for contacts.  # noqa: E501

        :return: The xero_network_key of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._xero_network_key

    @xero_network_key.setter
    def xero_network_key(self, xero_network_key):
        """Sets the xero_network_key of this Contact.

        Store XeroNetworkKey for contacts.  # noqa: E501

        :param xero_network_key: The xero_network_key of this Contact.  # noqa: E501
        :type: str
        """

        self._xero_network_key = xero_network_key

    @property
    def sales_default_account_code(self):
        """Gets the sales_default_account_code of this Contact.  # noqa: E501

        The default sales account code for contacts  # noqa: E501

        :return: The sales_default_account_code of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._sales_default_account_code

    @sales_default_account_code.setter
    def sales_default_account_code(self, sales_default_account_code):
        """Sets the sales_default_account_code of this Contact.

        The default sales account code for contacts  # noqa: E501

        :param sales_default_account_code: The sales_default_account_code of this Contact.  # noqa: E501
        :type: str
        """

        self._sales_default_account_code = sales_default_account_code

    @property
    def purchases_default_account_code(self):
        """Gets the purchases_default_account_code of this Contact.  # noqa: E501

        The default purchases account code for contacts  # noqa: E501

        :return: The purchases_default_account_code of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._purchases_default_account_code

    @purchases_default_account_code.setter
    def purchases_default_account_code(self, purchases_default_account_code):
        """Sets the purchases_default_account_code of this Contact.

        The default purchases account code for contacts  # noqa: E501

        :param purchases_default_account_code: The purchases_default_account_code of this Contact.  # noqa: E501
        :type: str
        """

        self._purchases_default_account_code = purchases_default_account_code

    @property
    def sales_tracking_categories(self):
        """Gets the sales_tracking_categories of this Contact.  # noqa: E501

        The default sales tracking categories for contacts  # noqa: E501

        :return: The sales_tracking_categories of this Contact.  # noqa: E501
        :rtype: list[SalesTrackingCategory]
        """
        return self._sales_tracking_categories

    @sales_tracking_categories.setter
    def sales_tracking_categories(self, sales_tracking_categories):
        """Sets the sales_tracking_categories of this Contact.

        The default sales tracking categories for contacts  # noqa: E501

        :param sales_tracking_categories: The sales_tracking_categories of this Contact.  # noqa: E501
        :type: list[SalesTrackingCategory]
        """

        self._sales_tracking_categories = sales_tracking_categories

    @property
    def purchases_tracking_categories(self):
        """Gets the purchases_tracking_categories of this Contact.  # noqa: E501

        The default purchases tracking categories for contacts  # noqa: E501

        :return: The purchases_tracking_categories of this Contact.  # noqa: E501
        :rtype: list[SalesTrackingCategory]
        """
        return self._purchases_tracking_categories

    @purchases_tracking_categories.setter
    def purchases_tracking_categories(self, purchases_tracking_categories):
        """Sets the purchases_tracking_categories of this Contact.

        The default purchases tracking categories for contacts  # noqa: E501

        :param purchases_tracking_categories: The purchases_tracking_categories of this Contact.  # noqa: E501
        :type: list[SalesTrackingCategory]
        """

        self._purchases_tracking_categories = purchases_tracking_categories

    @property
    def tracking_category_name(self):
        """Gets the tracking_category_name of this Contact.  # noqa: E501

        The name of the Tracking Category assigned to the contact under SalesTrackingCategories and PurchasesTrackingCategories  # noqa: E501

        :return: The tracking_category_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._tracking_category_name

    @tracking_category_name.setter
    def tracking_category_name(self, tracking_category_name):
        """Sets the tracking_category_name of this Contact.

        The name of the Tracking Category assigned to the contact under SalesTrackingCategories and PurchasesTrackingCategories  # noqa: E501

        :param tracking_category_name: The tracking_category_name of this Contact.  # noqa: E501
        :type: str
        """

        self._tracking_category_name = tracking_category_name

    @property
    def tracking_category_option(self):
        """Gets the tracking_category_option of this Contact.  # noqa: E501

        The name of the Tracking Option assigned to the contact under SalesTrackingCategories and PurchasesTrackingCategories  # noqa: E501

        :return: The tracking_category_option of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._tracking_category_option

    @tracking_category_option.setter
    def tracking_category_option(self, tracking_category_option):
        """Sets the tracking_category_option of this Contact.

        The name of the Tracking Option assigned to the contact under SalesTrackingCategories and PurchasesTrackingCategories  # noqa: E501

        :param tracking_category_option: The tracking_category_option of this Contact.  # noqa: E501
        :type: str
        """

        self._tracking_category_option = tracking_category_option

    @property
    def payment_terms(self):
        """Gets the payment_terms of this Contact.  # noqa: E501


        :return: The payment_terms of this Contact.  # noqa: E501
        :rtype: PaymentTerm
        """
        return self._payment_terms

    @payment_terms.setter
    def payment_terms(self, payment_terms):
        """Sets the payment_terms of this Contact.


        :param payment_terms: The payment_terms of this Contact.  # noqa: E501
        :type: PaymentTerm
        """

        self._payment_terms = payment_terms

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Contact.  # noqa: E501

        UTC timestamp of last update to contact  # noqa: E501

        :return: The updated_date_utc of this Contact.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Contact.

        UTC timestamp of last update to contact  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Contact.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def contact_groups(self):
        """Gets the contact_groups of this Contact.  # noqa: E501

        Displays which contact groups a contact is included in  # noqa: E501

        :return: The contact_groups of this Contact.  # noqa: E501
        :rtype: list[ContactGroup]
        """
        return self._contact_groups

    @contact_groups.setter
    def contact_groups(self, contact_groups):
        """Sets the contact_groups of this Contact.

        Displays which contact groups a contact is included in  # noqa: E501

        :param contact_groups: The contact_groups of this Contact.  # noqa: E501
        :type: list[ContactGroup]
        """

        self._contact_groups = contact_groups

    @property
    def website(self):
        """Gets the website of this Contact.  # noqa: E501

        Website address for contact (read only)  # noqa: E501

        :return: The website of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website):
        """Sets the website of this Contact.

        Website address for contact (read only)  # noqa: E501

        :param website: The website of this Contact.  # noqa: E501
        :type: str
        """

        self._website = website

    @property
    def branding_theme(self):
        """Gets the branding_theme of this Contact.  # noqa: E501


        :return: The branding_theme of this Contact.  # noqa: E501
        :rtype: BrandingTheme
        """
        return self._branding_theme

    @branding_theme.setter
    def branding_theme(self, branding_theme):
        """Sets the branding_theme of this Contact.


        :param branding_theme: The branding_theme of this Contact.  # noqa: E501
        :type: BrandingTheme
        """

        self._branding_theme = branding_theme

    @property
    def batch_payments(self):
        """Gets the batch_payments of this Contact.  # noqa: E501


        :return: The batch_payments of this Contact.  # noqa: E501
        :rtype: BatchPaymentDetails
        """
        return self._batch_payments

    @batch_payments.setter
    def batch_payments(self, batch_payments):
        """Sets the batch_payments of this Contact.


        :param batch_payments: The batch_payments of this Contact.  # noqa: E501
        :type: BatchPaymentDetails
        """

        self._batch_payments = batch_payments

    @property
    def discount(self):
        """Gets the discount of this Contact.  # noqa: E501

        The default discount rate for the contact (read only)  # noqa: E501

        :return: The discount of this Contact.  # noqa: E501
        :rtype: float
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this Contact.

        The default discount rate for the contact (read only)  # noqa: E501

        :param discount: The discount of this Contact.  # noqa: E501
        :type: float
        """

        self._discount = discount

    @property
    def balances(self):
        """Gets the balances of this Contact.  # noqa: E501


        :return: The balances of this Contact.  # noqa: E501
        :rtype: Balances
        """
        return self._balances

    @balances.setter
    def balances(self, balances):
        """Sets the balances of this Contact.


        :param balances: The balances of this Contact.  # noqa: E501
        :type: Balances
        """

        self._balances = balances

    @property
    def attachments(self):
        """Gets the attachments of this Contact.  # noqa: E501

        Displays array of attachments from the API  # noqa: E501

        :return: The attachments of this Contact.  # noqa: E501
        :rtype: list[Attachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this Contact.

        Displays array of attachments from the API  # noqa: E501

        :param attachments: The attachments of this Contact.  # noqa: E501
        :type: list[Attachment]
        """

        self._attachments = attachments

    @property
    def has_attachments(self):
        """Gets the has_attachments of this Contact.  # noqa: E501

        A boolean to indicate if a contact has an attachment  # noqa: E501

        :return: The has_attachments of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._has_attachments

    @has_attachments.setter
    def has_attachments(self, has_attachments):
        """Sets the has_attachments of this Contact.

        A boolean to indicate if a contact has an attachment  # noqa: E501

        :param has_attachments: The has_attachments of this Contact.  # noqa: E501
        :type: bool
        """

        self._has_attachments = has_attachments

    @property
    def validation_errors(self):
        """Gets the validation_errors of this Contact.  # noqa: E501

        Displays validation errors returned from the API  # noqa: E501

        :return: The validation_errors of this Contact.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this Contact.

        Displays validation errors returned from the API  # noqa: E501

        :param validation_errors: The validation_errors of this Contact.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors

    @property
    def has_validation_errors(self):
        """Gets the has_validation_errors of this Contact.  # noqa: E501

        A boolean to indicate if a contact has an validation errors  # noqa: E501

        :return: The has_validation_errors of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._has_validation_errors

    @has_validation_errors.setter
    def has_validation_errors(self, has_validation_errors):
        """Sets the has_validation_errors of this Contact.

        A boolean to indicate if a contact has an validation errors  # noqa: E501

        :param has_validation_errors: The has_validation_errors of this Contact.  # noqa: E501
        :type: bool
        """

        self._has_validation_errors = has_validation_errors

    @property
    def status_attribute_string(self):
        """Gets the status_attribute_string of this Contact.  # noqa: E501

        Status of object  # noqa: E501

        :return: The status_attribute_string of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._status_attribute_string

    @status_attribute_string.setter
    def status_attribute_string(self, status_attribute_string):
        """Sets the status_attribute_string of this Contact.

        Status of object  # noqa: E501

        :param status_attribute_string: The status_attribute_string of this Contact.  # noqa: E501
        :type: str
        """

        self._status_attribute_string = status_attribute_string



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class BankTransactions(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"bank_transactions": "list[BankTransaction]"}

    attribute_map = {"bank_transactions": "BankTransactions"}

    def __init__(self, bank_transactions=None):  # noqa: E501
        """BankTransactions - a model defined in OpenAPI"""  # noqa: E501

        self._bank_transactions = None
        self.discriminator = None

        if bank_transactions is not None:
            self.bank_transactions = bank_transactions

    @property
    def bank_transactions(self):
        """Gets the bank_transactions of this BankTransactions.  # noqa: E501


        :return: The bank_transactions of this BankTransactions.  # noqa: E501
        :rtype: list[BankTransaction]
        """
        return self._bank_transactions

    @bank_transactions.setter
    def bank_transactions(self, bank_transactions):
        """Sets the bank_transactions of this BankTransactions.


        :param bank_transactions: The bank_transactions of this BankTransactions.  # noqa: E501
        :type: list[BankTransaction]
        """

        self._bank_transactions = bank_transactions



# coding: utf-8

"""
    Xero Assets API

    The Assets API exposes fixed asset related functions of the Xero Accounting application and can be used for a variety of purposes such as creating assets, retrieving asset valuations etc.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class BookDepreciationDetail(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "current_capital_gain": "float",
        "current_gain_loss": "float",
        "depreciation_start_date": "date",
        "cost_limit": "float",
        "residual_value": "float",
        "prior_accum_depreciation_amount": "float",
        "current_accum_depreciation_amount": "float",
    }

    attribute_map = {
        "current_capital_gain": "currentCapitalGain",
        "current_gain_loss": "currentGainLoss",
        "depreciation_start_date": "depreciationStartDate",
        "cost_limit": "costLimit",
        "residual_value": "residualValue",
        "prior_accum_depreciation_amount": "priorAccumDepreciationAmount",
        "current_accum_depreciation_amount": "currentAccumDepreciationAmount",
    }

    def __init__(
        self,
        current_capital_gain=None,
        current_gain_loss=None,
        depreciation_start_date=None,
        cost_limit=None,
        residual_value=None,
        prior_accum_depreciation_amount=None,
        current_accum_depreciation_amount=None,
    ):  # noqa: E501
        """BookDepreciationDetail - a model defined in OpenAPI"""  # noqa: E501

        self._current_capital_gain = None
        self._current_gain_loss = None
        self._depreciation_start_date = None
        self._cost_limit = None
        self._residual_value = None
        self._prior_accum_depreciation_amount = None
        self._current_accum_depreciation_amount = None
        self.discriminator = None

        if current_capital_gain is not None:
            self.current_capital_gain = current_capital_gain
        if current_gain_loss is not None:
            self.current_gain_loss = current_gain_loss
        if depreciation_start_date is not None:
            self.depreciation_start_date = depreciation_start_date
        if cost_limit is not None:
            self.cost_limit = cost_limit
        if residual_value is not None:
            self.residual_value = residual_value
        if prior_accum_depreciation_amount is not None:
            self.prior_accum_depreciation_amount = prior_accum_depreciation_amount
        if current_accum_depreciation_amount is not None:
            self.current_accum_depreciation_amount = current_accum_depreciation_amount

    @property
    def current_capital_gain(self):
        """Gets the current_capital_gain of this BookDepreciationDetail.  # noqa: E501

        When an asset is disposed, this will be the sell price minus the purchase price if a profit was made.  # noqa: E501

        :return: The current_capital_gain of this BookDepreciationDetail.  # noqa: E501
        :rtype: float
        """
        return self._current_capital_gain

    @current_capital_gain.setter
    def current_capital_gain(self, current_capital_gain):
        """Sets the current_capital_gain of this BookDepreciationDetail.

        When an asset is disposed, this will be the sell price minus the purchase price if a profit was made.  # noqa: E501

        :param current_capital_gain: The current_capital_gain of this BookDepreciationDetail.  # noqa: E501
        :type: float
        """

        self._current_capital_gain = current_capital_gain

    @property
    def current_gain_loss(self):
        """Gets the current_gain_loss of this BookDepreciationDetail.  # noqa: E501

        When an asset is disposed, this will be the lowest one of sell price or purchase price, minus the current book value.  # noqa: E501

        :return: The current_gain_loss of this BookDepreciationDetail.  # noqa: E501
        :rtype: float
        """
        return self._current_gain_loss

    @current_gain_loss.setter
    def current_gain_loss(self, current_gain_loss):
        """Sets the current_gain_loss of this BookDepreciationDetail.

        When an asset is disposed, this will be the lowest one of sell price or purchase price, minus the current book value.  # noqa: E501

        :param current_gain_loss: The current_gain_loss of this BookDepreciationDetail.  # noqa: E501
        :type: float
        """

        self._current_gain_loss = current_gain_loss

    @property
    def depreciation_start_date(self):
        """Gets the depreciation_start_date of this BookDepreciationDetail.  # noqa: E501

        YYYY-MM-DD  # noqa: E501

        :return: The depreciation_start_date of this BookDepreciationDetail.  # noqa: E501
        :rtype: date
        """
        return self._depreciation_start_date

    @depreciation_start_date.setter
    def depreciation_start_date(self, depreciation_start_date):
        """Sets the depreciation_start_date of this BookDepreciationDetail.

        YYYY-MM-DD  # noqa: E501

        :param depreciation_start_date: The depreciation_start_date of this BookDepreciationDetail.  # noqa: E501
        :type: date
        """

        self._depreciation_start_date = depreciation_start_date

    @property
    def cost_limit(self):
        """Gets the cost_limit of this BookDepreciationDetail.  # noqa: E501

        The value of the asset you want to depreciate, if this is less than the cost of the asset.  # noqa: E501

        :return: The cost_limit of this BookDepreciationDetail.  # noqa: E501
        :rtype: float
        """
        return self._cost_limit

    @cost_limit.setter
    def cost_limit(self, cost_limit):
        """Sets the cost_limit of this BookDepreciationDetail.

        The value of the asset you want to depreciate, if this is less than the cost of the asset.  # noqa: E501

        :param cost_limit: The cost_limit of this BookDepreciationDetail.  # noqa: E501
        :type: float
        """

        self._cost_limit = cost_limit

    @property
    def residual_value(self):
        """Gets the residual_value of this BookDepreciationDetail.  # noqa: E501

        The value of the asset remaining when you've fully depreciated it.  # noqa: E501

        :return: The residual_value of this BookDepreciationDetail.  # noqa: E501
        :rtype: float
        """
        return self._residual_value

    @residual_value.setter
    def residual_value(self, residual_value):
        """Sets the residual_value of this BookDepreciationDetail.

        The value of the asset remaining when you've fully depreciated it.  # noqa: E501

        :param residual_value: The residual_value of this BookDepreciationDetail.  # noqa: E501
        :type: float
        """

        self._residual_value = residual_value

    @property
    def prior_accum_depreciation_amount(self):
        """Gets the prior_accum_depreciation_amount of this BookDepreciationDetail.  # noqa: E501

        All depreciation prior to the current financial year.  # noqa: E501

        :return: The prior_accum_depreciation_amount of this BookDepreciationDetail.  # noqa: E501
        :rtype: float
        """
        return self._prior_accum_depreciation_amount

    @prior_accum_depreciation_amount.setter
    def prior_accum_depreciation_amount(self, prior_accum_depreciation_amount):
        """Sets the prior_accum_depreciation_amount of this BookDepreciationDetail.

        All depreciation prior to the current financial year.  # noqa: E501

        :param prior_accum_depreciation_amount: The prior_accum_depreciation_amount of this BookDepreciationDetail.  # noqa: E501
        :type: float
        """

        self._prior_accum_depreciation_amount = prior_accum_depreciation_amount

    @property
    def current_accum_depreciation_amount(self):
        """Gets the current_accum_depreciation_amount of this BookDepreciationDetail.  # noqa: E501

        All depreciation occurring in the current financial year.  # noqa: E501

        :return: The current_accum_depreciation_amount of this BookDepreciationDetail.  # noqa: E501
        :rtype: float
        """
        return self._current_accum_depreciation_amount

    @current_accum_depreciation_amount.setter
    def current_accum_depreciation_amount(self, current_accum_depreciation_amount):
        """Sets the current_accum_depreciation_amount of this BookDepreciationDetail.

        All depreciation occurring in the current financial year.  # noqa: E501

        :param current_accum_depreciation_amount: The current_accum_depreciation_amount of this BookDepreciationDetail.  # noqa: E501
        :type: float
        """

        self._current_accum_depreciation_amount = current_accum_depreciation_amount



# coding: utf-8

"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Files(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "total_count": "int",
        "page": "int",
        "per_page": "int",
        "items": "list[FileObject]",
    }

    attribute_map = {
        "total_count": "TotalCount",
        "page": "Page",
        "per_page": "PerPage",
        "items": "Items",
    }

    def __init__(
        self, total_count=None, page=None, per_page=None, items=None
    ):  # noqa: E501
        """Files - a model defined in OpenAPI"""  # noqa: E501

        self._total_count = None
        self._page = None
        self._per_page = None
        self._items = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if page is not None:
            self.page = page
        if per_page is not None:
            self.per_page = per_page
        if items is not None:
            self.items = items

    @property
    def total_count(self):
        """Gets the total_count of this Files.  # noqa: E501


        :return: The total_count of this Files.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this Files.


        :param total_count: The total_count of this Files.  # noqa: E501
        :type: int
        """

        self._total_count = total_count

    @property
    def page(self):
        """Gets the page of this Files.  # noqa: E501


        :return: The page of this Files.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this Files.


        :param page: The page of this Files.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def per_page(self):
        """Gets the per_page of this Files.  # noqa: E501


        :return: The per_page of this Files.  # noqa: E501
        :rtype: int
        """
        return self._per_page

    @per_page.setter
    def per_page(self, per_page):
        """Sets the per_page of this Files.


        :param per_page: The per_page of this Files.  # noqa: E501
        :type: int
        """

        self._per_page = per_page

    @property
    def items(self):
        """Gets the items of this Files.  # noqa: E501


        :return: The items of this Files.  # noqa: E501
        :rtype: list[FileObject]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this Files.


        :param items: The items of this Files.  # noqa: E501
        :type: list[FileObject]
        """

        self._items = items



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Employee(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "first_name": "str",
        "last_name": "str",
        "date_of_birth": "date[ms-format]",
        "home_address": "HomeAddress",
        "start_date": "date[ms-format]",
        "title": "str",
        "middle_names": "str",
        "email": "str",
        "gender": "str",
        "phone": "str",
        "mobile": "str",
        "twitter_user_name": "str",
        "is_authorised_to_approve_leave": "bool",
        "is_authorised_to_approve_timesheets": "bool",
        "job_title": "str",
        "classification": "str",
        "ordinary_earnings_rate_id": "str",
        "payroll_calendar_id": "str",
        "employee_group_name": "str",
        "employee_id": "str",
        "termination_date": "date[ms-format]",
        "bank_accounts": "list[BankAccount]",
        "pay_template": "PayTemplate",
        "opening_balances": "OpeningBalances",
        "tax_declaration": "TaxDeclaration",
        "leave_balances": "list[LeaveBalance]",
        "leave_lines": "list[LeaveLine]",
        "super_memberships": "list[SuperMembership]",
        "status": "EmployeeStatus",
        "updated_date_utc": "datetime[ms-format]",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "first_name": "FirstName",
        "last_name": "LastName",
        "date_of_birth": "DateOfBirth",
        "home_address": "HomeAddress",
        "start_date": "StartDate",
        "title": "Title",
        "middle_names": "MiddleNames",
        "email": "Email",
        "gender": "Gender",
        "phone": "Phone",
        "mobile": "Mobile",
        "twitter_user_name": "TwitterUserName",
        "is_authorised_to_approve_leave": "IsAuthorisedToApproveLeave",
        "is_authorised_to_approve_timesheets": "IsAuthorisedToApproveTimesheets",
        "job_title": "JobTitle",
        "classification": "Classification",
        "ordinary_earnings_rate_id": "OrdinaryEarningsRateID",
        "payroll_calendar_id": "PayrollCalendarID",
        "employee_group_name": "EmployeeGroupName",
        "employee_id": "EmployeeID",
        "termination_date": "TerminationDate",
        "bank_accounts": "BankAccounts",
        "pay_template": "PayTemplate",
        "opening_balances": "OpeningBalances",
        "tax_declaration": "TaxDeclaration",
        "leave_balances": "LeaveBalances",
        "leave_lines": "LeaveLines",
        "super_memberships": "SuperMemberships",
        "status": "Status",
        "updated_date_utc": "UpdatedDateUTC",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        first_name=None,
        last_name=None,
        date_of_birth=None,
        home_address=None,
        start_date=None,
        title=None,
        middle_names=None,
        email=None,
        gender=None,
        phone=None,
        mobile=None,
        twitter_user_name=None,
        is_authorised_to_approve_leave=None,
        is_authorised_to_approve_timesheets=None,
        job_title=None,
        classification=None,
        ordinary_earnings_rate_id=None,
        payroll_calendar_id=None,
        employee_group_name=None,
        employee_id=None,
        termination_date=None,
        bank_accounts=None,
        pay_template=None,
        opening_balances=None,
        tax_declaration=None,
        leave_balances=None,
        leave_lines=None,
        super_memberships=None,
        status=None,
        updated_date_utc=None,
        validation_errors=None,
    ):  # noqa: E501
        """Employee - a model defined in OpenAPI"""  # noqa: E501

        self._first_name = None
        self._last_name = None
        self._date_of_birth = None
        self._home_address = None
        self._start_date = None
        self._title = None
        self._middle_names = None
        self._email = None
        self._gender = None
        self._phone = None
        self._mobile = None
        self._twitter_user_name = None
        self._is_authorised_to_approve_leave = None
        self._is_authorised_to_approve_timesheets = None
        self._job_title = None
        self._classification = None
        self._ordinary_earnings_rate_id = None
        self._payroll_calendar_id = None
        self._employee_group_name = None
        self._employee_id = None
        self._termination_date = None
        self._bank_accounts = None
        self._pay_template = None
        self._opening_balances = None
        self._tax_declaration = None
        self._leave_balances = None
        self._leave_lines = None
        self._super_memberships = None
        self._status = None
        self._updated_date_utc = None
        self._validation_errors = None
        self.discriminator = None

        self.first_name = first_name
        self.last_name = last_name
        self.date_of_birth = date_of_birth
        if home_address is not None:
            self.home_address = home_address
        if start_date is not None:
            self.start_date = start_date
        if title is not None:
            self.title = title
        if middle_names is not None:
            self.middle_names = middle_names
        if email is not None:
            self.email = email
        if gender is not None:
            self.gender = gender
        if phone is not None:
            self.phone = phone
        if mobile is not None:
            self.mobile = mobile
        if twitter_user_name is not None:
            self.twitter_user_name = twitter_user_name
        if is_authorised_to_approve_leave is not None:
            self.is_authorised_to_approve_leave = is_authorised_to_approve_leave
        if is_authorised_to_approve_timesheets is not None:
            self.is_authorised_to_approve_timesheets = (
                is_authorised_to_approve_timesheets
            )
        if job_title is not None:
            self.job_title = job_title
        if classification is not None:
            self.classification = classification
        if ordinary_earnings_rate_id is not None:
            self.ordinary_earnings_rate_id = ordinary_earnings_rate_id
        if payroll_calendar_id is not None:
            self.payroll_calendar_id = payroll_calendar_id
        if employee_group_name is not None:
            self.employee_group_name = employee_group_name
        if employee_id is not None:
            self.employee_id = employee_id
        if termination_date is not None:
            self.termination_date = termination_date
        if bank_accounts is not None:
            self.bank_accounts = bank_accounts
        if pay_template is not None:
            self.pay_template = pay_template
        if opening_balances is not None:
            self.opening_balances = opening_balances
        if tax_declaration is not None:
            self.tax_declaration = tax_declaration
        if leave_balances is not None:
            self.leave_balances = leave_balances
        if leave_lines is not None:
            self.leave_lines = leave_lines
        if super_memberships is not None:
            self.super_memberships = super_memberships
        if status is not None:
            self.status = status
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def first_name(self):
        """Gets the first_name of this Employee.  # noqa: E501

        First name of employee  # noqa: E501

        :return: The first_name of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Employee.

        First name of employee  # noqa: E501

        :param first_name: The first_name of this Employee.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError(
                "Invalid value for `first_name`, must not be `None`"
            )  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this Employee.  # noqa: E501

        Last name of employee  # noqa: E501

        :return: The last_name of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Employee.

        Last name of employee  # noqa: E501

        :param last_name: The last_name of this Employee.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError(
                "Invalid value for `last_name`, must not be `None`"
            )  # noqa: E501

        self._last_name = last_name

    @property
    def date_of_birth(self):
        """Gets the date_of_birth of this Employee.  # noqa: E501

        Date of birth of the employee (YYYY-MM-DD)  # noqa: E501

        :return: The date_of_birth of this Employee.  # noqa: E501
        :rtype: date
        """
        return self._date_of_birth

    @date_of_birth.setter
    def date_of_birth(self, date_of_birth):
        """Sets the date_of_birth of this Employee.

        Date of birth of the employee (YYYY-MM-DD)  # noqa: E501

        :param date_of_birth: The date_of_birth of this Employee.  # noqa: E501
        :type: date
        """
        if date_of_birth is None:
            raise ValueError(
                "Invalid value for `date_of_birth`, must not be `None`"
            )  # noqa: E501

        self._date_of_birth = date_of_birth

    @property
    def home_address(self):
        """Gets the home_address of this Employee.  # noqa: E501


        :return: The home_address of this Employee.  # noqa: E501
        :rtype: HomeAddress
        """
        return self._home_address

    @home_address.setter
    def home_address(self, home_address):
        """Sets the home_address of this Employee.


        :param home_address: The home_address of this Employee.  # noqa: E501
        :type: HomeAddress
        """

        self._home_address = home_address

    @property
    def start_date(self):
        """Gets the start_date of this Employee.  # noqa: E501

        Start date for an employee (YYYY-MM-DD)  # noqa: E501

        :return: The start_date of this Employee.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Employee.

        Start date for an employee (YYYY-MM-DD)  # noqa: E501

        :param start_date: The start_date of this Employee.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def title(self):
        """Gets the title of this Employee.  # noqa: E501

        Title of the employee  # noqa: E501

        :return: The title of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Employee.

        Title of the employee  # noqa: E501

        :param title: The title of this Employee.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def middle_names(self):
        """Gets the middle_names of this Employee.  # noqa: E501

        Middle name(s) of the employee  # noqa: E501

        :return: The middle_names of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._middle_names

    @middle_names.setter
    def middle_names(self, middle_names):
        """Sets the middle_names of this Employee.

        Middle name(s) of the employee  # noqa: E501

        :param middle_names: The middle_names of this Employee.  # noqa: E501
        :type: str
        """

        self._middle_names = middle_names

    @property
    def email(self):
        """Gets the email of this Employee.  # noqa: E501

        The email address for the employee  # noqa: E501

        :return: The email of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Employee.

        The email address for the employee  # noqa: E501

        :param email: The email of this Employee.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def gender(self):
        """Gets the gender of this Employee.  # noqa: E501

        The employee’s gender. See Employee Gender  # noqa: E501

        :return: The gender of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this Employee.

        The employee’s gender. See Employee Gender  # noqa: E501

        :param gender: The gender of this Employee.  # noqa: E501
        :type: str
        """
        allowed_values = ["N", "M", "F", "I", "None"]  # noqa: E501

        if gender:
            if gender not in allowed_values:
                raise ValueError(
                    "Invalid value for `gender` ({0}), must be one of {1}".format(  # noqa: E501
                        gender, allowed_values
                    )
                )

        self._gender = gender

    @property
    def phone(self):
        """Gets the phone of this Employee.  # noqa: E501

        Employee phone number  # noqa: E501

        :return: The phone of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this Employee.

        Employee phone number  # noqa: E501

        :param phone: The phone of this Employee.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def mobile(self):
        """Gets the mobile of this Employee.  # noqa: E501

        Employee mobile number  # noqa: E501

        :return: The mobile of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._mobile

    @mobile.setter
    def mobile(self, mobile):
        """Sets the mobile of this Employee.

        Employee mobile number  # noqa: E501

        :param mobile: The mobile of this Employee.  # noqa: E501
        :type: str
        """

        self._mobile = mobile

    @property
    def twitter_user_name(self):
        """Gets the twitter_user_name of this Employee.  # noqa: E501

        Employee’s twitter name  # noqa: E501

        :return: The twitter_user_name of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._twitter_user_name

    @twitter_user_name.setter
    def twitter_user_name(self, twitter_user_name):
        """Sets the twitter_user_name of this Employee.

        Employee’s twitter name  # noqa: E501

        :param twitter_user_name: The twitter_user_name of this Employee.  # noqa: E501
        :type: str
        """

        self._twitter_user_name = twitter_user_name

    @property
    def is_authorised_to_approve_leave(self):
        """Gets the is_authorised_to_approve_leave of this Employee.  # noqa: E501

        Authorised to approve other employees' leave requests  # noqa: E501

        :return: The is_authorised_to_approve_leave of this Employee.  # noqa: E501
        :rtype: bool
        """
        return self._is_authorised_to_approve_leave

    @is_authorised_to_approve_leave.setter
    def is_authorised_to_approve_leave(self, is_authorised_to_approve_leave):
        """Sets the is_authorised_to_approve_leave of this Employee.

        Authorised to approve other employees' leave requests  # noqa: E501

        :param is_authorised_to_approve_leave: The is_authorised_to_approve_leave of this Employee.  # noqa: E501
        :type: bool
        """

        self._is_authorised_to_approve_leave = is_authorised_to_approve_leave

    @property
    def is_authorised_to_approve_timesheets(self):
        """Gets the is_authorised_to_approve_timesheets of this Employee.  # noqa: E501

        Authorised to approve timesheets  # noqa: E501

        :return: The is_authorised_to_approve_timesheets of this Employee.  # noqa: E501
        :rtype: bool
        """
        return self._is_authorised_to_approve_timesheets

    @is_authorised_to_approve_timesheets.setter
    def is_authorised_to_approve_timesheets(self, is_authorised_to_approve_timesheets):
        """Sets the is_authorised_to_approve_timesheets of this Employee.

        Authorised to approve timesheets  # noqa: E501

        :param is_authorised_to_approve_timesheets: The is_authorised_to_approve_timesheets of this Employee.  # noqa: E501
        :type: bool
        """

        self._is_authorised_to_approve_timesheets = is_authorised_to_approve_timesheets

    @property
    def job_title(self):
        """Gets the job_title of this Employee.  # noqa: E501

        JobTitle of the employee  # noqa: E501

        :return: The job_title of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this Employee.

        JobTitle of the employee  # noqa: E501

        :param job_title: The job_title of this Employee.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def classification(self):
        """Gets the classification of this Employee.  # noqa: E501

        Employees classification  # noqa: E501

        :return: The classification of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        """Sets the classification of this Employee.

        Employees classification  # noqa: E501

        :param classification: The classification of this Employee.  # noqa: E501
        :type: str
        """

        self._classification = classification

    @property
    def ordinary_earnings_rate_id(self):
        """Gets the ordinary_earnings_rate_id of this Employee.  # noqa: E501

        Xero unique identifier for earnings rate  # noqa: E501

        :return: The ordinary_earnings_rate_id of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._ordinary_earnings_rate_id

    @ordinary_earnings_rate_id.setter
    def ordinary_earnings_rate_id(self, ordinary_earnings_rate_id):
        """Sets the ordinary_earnings_rate_id of this Employee.

        Xero unique identifier for earnings rate  # noqa: E501

        :param ordinary_earnings_rate_id: The ordinary_earnings_rate_id of this Employee.  # noqa: E501
        :type: str
        """

        self._ordinary_earnings_rate_id = ordinary_earnings_rate_id

    @property
    def payroll_calendar_id(self):
        """Gets the payroll_calendar_id of this Employee.  # noqa: E501

        Xero unique identifier for payroll calendar for the employee  # noqa: E501

        :return: The payroll_calendar_id of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._payroll_calendar_id

    @payroll_calendar_id.setter
    def payroll_calendar_id(self, payroll_calendar_id):
        """Sets the payroll_calendar_id of this Employee.

        Xero unique identifier for payroll calendar for the employee  # noqa: E501

        :param payroll_calendar_id: The payroll_calendar_id of this Employee.  # noqa: E501
        :type: str
        """

        self._payroll_calendar_id = payroll_calendar_id

    @property
    def employee_group_name(self):
        """Gets the employee_group_name of this Employee.  # noqa: E501

        The Employee Group allows you to report on payroll expenses and liabilities for each group of employees  # noqa: E501

        :return: The employee_group_name of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._employee_group_name

    @employee_group_name.setter
    def employee_group_name(self, employee_group_name):
        """Sets the employee_group_name of this Employee.

        The Employee Group allows you to report on payroll expenses and liabilities for each group of employees  # noqa: E501

        :param employee_group_name: The employee_group_name of this Employee.  # noqa: E501
        :type: str
        """

        self._employee_group_name = employee_group_name

    @property
    def employee_id(self):
        """Gets the employee_id of this Employee.  # noqa: E501

        Xero unique identifier for an Employee  # noqa: E501

        :return: The employee_id of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this Employee.

        Xero unique identifier for an Employee  # noqa: E501

        :param employee_id: The employee_id of this Employee.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def termination_date(self):
        """Gets the termination_date of this Employee.  # noqa: E501

        Employee Termination Date (YYYY-MM-DD)  # noqa: E501

        :return: The termination_date of this Employee.  # noqa: E501
        :rtype: date
        """
        return self._termination_date

    @termination_date.setter
    def termination_date(self, termination_date):
        """Sets the termination_date of this Employee.

        Employee Termination Date (YYYY-MM-DD)  # noqa: E501

        :param termination_date: The termination_date of this Employee.  # noqa: E501
        :type: date
        """

        self._termination_date = termination_date

    @property
    def bank_accounts(self):
        """Gets the bank_accounts of this Employee.  # noqa: E501


        :return: The bank_accounts of this Employee.  # noqa: E501
        :rtype: list[BankAccount]
        """
        return self._bank_accounts

    @bank_accounts.setter
    def bank_accounts(self, bank_accounts):
        """Sets the bank_accounts of this Employee.


        :param bank_accounts: The bank_accounts of this Employee.  # noqa: E501
        :type: list[BankAccount]
        """

        self._bank_accounts = bank_accounts

    @property
    def pay_template(self):
        """Gets the pay_template of this Employee.  # noqa: E501


        :return: The pay_template of this Employee.  # noqa: E501
        :rtype: PayTemplate
        """
        return self._pay_template

    @pay_template.setter
    def pay_template(self, pay_template):
        """Sets the pay_template of this Employee.


        :param pay_template: The pay_template of this Employee.  # noqa: E501
        :type: PayTemplate
        """

        self._pay_template = pay_template

    @property
    def opening_balances(self):
        """Gets the opening_balances of this Employee.  # noqa: E501


        :return: The opening_balances of this Employee.  # noqa: E501
        :rtype: OpeningBalances
        """
        return self._opening_balances

    @opening_balances.setter
    def opening_balances(self, opening_balances):
        """Sets the opening_balances of this Employee.


        :param opening_balances: The opening_balances of this Employee.  # noqa: E501
        :type: OpeningBalances
        """

        self._opening_balances = opening_balances

    @property
    def tax_declaration(self):
        """Gets the tax_declaration of this Employee.  # noqa: E501


        :return: The tax_declaration of this Employee.  # noqa: E501
        :rtype: TaxDeclaration
        """
        return self._tax_declaration

    @tax_declaration.setter
    def tax_declaration(self, tax_declaration):
        """Sets the tax_declaration of this Employee.


        :param tax_declaration: The tax_declaration of this Employee.  # noqa: E501
        :type: TaxDeclaration
        """

        self._tax_declaration = tax_declaration

    @property
    def leave_balances(self):
        """Gets the leave_balances of this Employee.  # noqa: E501


        :return: The leave_balances of this Employee.  # noqa: E501
        :rtype: list[LeaveBalance]
        """
        return self._leave_balances

    @leave_balances.setter
    def leave_balances(self, leave_balances):
        """Sets the leave_balances of this Employee.


        :param leave_balances: The leave_balances of this Employee.  # noqa: E501
        :type: list[LeaveBalance]
        """

        self._leave_balances = leave_balances

    @property
    def leave_lines(self):
        """Gets the leave_lines of this Employee.  # noqa: E501


        :return: The leave_lines of this Employee.  # noqa: E501
        :rtype: list[LeaveLine]
        """
        return self._leave_lines

    @leave_lines.setter
    def leave_lines(self, leave_lines):
        """Sets the leave_lines of this Employee.


        :param leave_lines: The leave_lines of this Employee.  # noqa: E501
        :type: list[LeaveLine]
        """

        self._leave_lines = leave_lines

    @property
    def super_memberships(self):
        """Gets the super_memberships of this Employee.  # noqa: E501


        :return: The super_memberships of this Employee.  # noqa: E501
        :rtype: list[SuperMembership]
        """
        return self._super_memberships

    @super_memberships.setter
    def super_memberships(self, super_memberships):
        """Sets the super_memberships of this Employee.


        :param super_memberships: The super_memberships of this Employee.  # noqa: E501
        :type: list[SuperMembership]
        """

        self._super_memberships = super_memberships

    @property
    def status(self):
        """Gets the status of this Employee.  # noqa: E501


        :return: The status of this Employee.  # noqa: E501
        :rtype: EmployeeStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Employee.


        :param status: The status of this Employee.  # noqa: E501
        :type: EmployeeStatus
        """

        self._status = status

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Employee.  # noqa: E501

        Last modified timestamp  # noqa: E501

        :return: The updated_date_utc of this Employee.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Employee.

        Last modified timestamp  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Employee.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def validation_errors(self):
        """Gets the validation_errors of this Employee.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this Employee.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this Employee.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this Employee.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PayrollCalendar(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "calendar_type": "CalendarType",
        "start_date": "date[ms-format]",
        "payment_date": "date[ms-format]",
        "payroll_calendar_id": "str",
        "updated_date_utc": "datetime[ms-format]",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "name": "Name",
        "calendar_type": "CalendarType",
        "start_date": "StartDate",
        "payment_date": "PaymentDate",
        "payroll_calendar_id": "PayrollCalendarID",
        "updated_date_utc": "UpdatedDateUTC",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        name=None,
        calendar_type=None,
        start_date=None,
        payment_date=None,
        payroll_calendar_id=None,
        updated_date_utc=None,
        validation_errors=None,
    ):  # noqa: E501
        """PayrollCalendar - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._calendar_type = None
        self._start_date = None
        self._payment_date = None
        self._payroll_calendar_id = None
        self._updated_date_utc = None
        self._validation_errors = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if calendar_type is not None:
            self.calendar_type = calendar_type
        if start_date is not None:
            self.start_date = start_date
        if payment_date is not None:
            self.payment_date = payment_date
        if payroll_calendar_id is not None:
            self.payroll_calendar_id = payroll_calendar_id
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def name(self):
        """Gets the name of this PayrollCalendar.  # noqa: E501

        Name of the Payroll Calendar  # noqa: E501

        :return: The name of this PayrollCalendar.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PayrollCalendar.

        Name of the Payroll Calendar  # noqa: E501

        :param name: The name of this PayrollCalendar.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def calendar_type(self):
        """Gets the calendar_type of this PayrollCalendar.  # noqa: E501


        :return: The calendar_type of this PayrollCalendar.  # noqa: E501
        :rtype: CalendarType
        """
        return self._calendar_type

    @calendar_type.setter
    def calendar_type(self, calendar_type):
        """Sets the calendar_type of this PayrollCalendar.


        :param calendar_type: The calendar_type of this PayrollCalendar.  # noqa: E501
        :type: CalendarType
        """

        self._calendar_type = calendar_type

    @property
    def start_date(self):
        """Gets the start_date of this PayrollCalendar.  # noqa: E501

        The start date of the upcoming pay period. The end date will be calculated based upon this date, and the calendar type selected (YYYY-MM-DD)  # noqa: E501

        :return: The start_date of this PayrollCalendar.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this PayrollCalendar.

        The start date of the upcoming pay period. The end date will be calculated based upon this date, and the calendar type selected (YYYY-MM-DD)  # noqa: E501

        :param start_date: The start_date of this PayrollCalendar.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def payment_date(self):
        """Gets the payment_date of this PayrollCalendar.  # noqa: E501

        The date on which employees will be paid for the upcoming pay period (YYYY-MM-DD)  # noqa: E501

        :return: The payment_date of this PayrollCalendar.  # noqa: E501
        :rtype: date
        """
        return self._payment_date

    @payment_date.setter
    def payment_date(self, payment_date):
        """Sets the payment_date of this PayrollCalendar.

        The date on which employees will be paid for the upcoming pay period (YYYY-MM-DD)  # noqa: E501

        :param payment_date: The payment_date of this PayrollCalendar.  # noqa: E501
        :type: date
        """

        self._payment_date = payment_date

    @property
    def payroll_calendar_id(self):
        """Gets the payroll_calendar_id of this PayrollCalendar.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The payroll_calendar_id of this PayrollCalendar.  # noqa: E501
        :rtype: str
        """
        return self._payroll_calendar_id

    @payroll_calendar_id.setter
    def payroll_calendar_id(self, payroll_calendar_id):
        """Sets the payroll_calendar_id of this PayrollCalendar.

        Xero identifier  # noqa: E501

        :param payroll_calendar_id: The payroll_calendar_id of this PayrollCalendar.  # noqa: E501
        :type: str
        """

        self._payroll_calendar_id = payroll_calendar_id

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this PayrollCalendar.  # noqa: E501

        Last modified timestamp  # noqa: E501

        :return: The updated_date_utc of this PayrollCalendar.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this PayrollCalendar.

        Last modified timestamp  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this PayrollCalendar.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def validation_errors(self):
        """Gets the validation_errors of this PayrollCalendar.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this PayrollCalendar.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this PayrollCalendar.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this PayrollCalendar.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Schedule(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "period": "int",
        "unit": "str",
        "due_date": "int",
        "due_date_type": "str",
        "start_date": "date[ms-format]",
        "next_scheduled_date": "date[ms-format]",
        "end_date": "date[ms-format]",
    }

    attribute_map = {
        "period": "Period",
        "unit": "Unit",
        "due_date": "DueDate",
        "due_date_type": "DueDateType",
        "start_date": "StartDate",
        "next_scheduled_date": "NextScheduledDate",
        "end_date": "EndDate",
    }

    def __init__(
        self,
        period=None,
        unit=None,
        due_date=None,
        due_date_type=None,
        start_date=None,
        next_scheduled_date=None,
        end_date=None,
    ):  # noqa: E501
        """Schedule - a model defined in OpenAPI"""  # noqa: E501

        self._period = None
        self._unit = None
        self._due_date = None
        self._due_date_type = None
        self._start_date = None
        self._next_scheduled_date = None
        self._end_date = None
        self.discriminator = None

        if period is not None:
            self.period = period
        if unit is not None:
            self.unit = unit
        if due_date is not None:
            self.due_date = due_date
        if due_date_type is not None:
            self.due_date_type = due_date_type
        if start_date is not None:
            self.start_date = start_date
        if next_scheduled_date is not None:
            self.next_scheduled_date = next_scheduled_date
        if end_date is not None:
            self.end_date = end_date

    @property
    def period(self):
        """Gets the period of this Schedule.  # noqa: E501

        Integer used with the unit e.g. 1 (every 1 week), 2 (every 2 months)  # noqa: E501

        :return: The period of this Schedule.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this Schedule.

        Integer used with the unit e.g. 1 (every 1 week), 2 (every 2 months)  # noqa: E501

        :param period: The period of this Schedule.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def unit(self):
        """Gets the unit of this Schedule.  # noqa: E501

        One of the following - WEEKLY or MONTHLY  # noqa: E501

        :return: The unit of this Schedule.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this Schedule.

        One of the following - WEEKLY or MONTHLY  # noqa: E501

        :param unit: The unit of this Schedule.  # noqa: E501
        :type: str
        """
        allowed_values = ["WEEKLY", "MONTHLY", "None"]  # noqa: E501

        if unit:
            if unit not in allowed_values:
                raise ValueError(
                    "Invalid value for `unit` ({0}), must be one of {1}".format(  # noqa: E501
                        unit, allowed_values
                    )
                )

        self._unit = unit

    @property
    def due_date(self):
        """Gets the due_date of this Schedule.  # noqa: E501

        Integer used with due date type e.g 20 (of following month), 31 (of current month)  # noqa: E501

        :return: The due_date of this Schedule.  # noqa: E501
        :rtype: int
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this Schedule.

        Integer used with due date type e.g 20 (of following month), 31 (of current month)  # noqa: E501

        :param due_date: The due_date of this Schedule.  # noqa: E501
        :type: int
        """

        self._due_date = due_date

    @property
    def due_date_type(self):
        """Gets the due_date_type of this Schedule.  # noqa: E501

        the payment terms  # noqa: E501

        :return: The due_date_type of this Schedule.  # noqa: E501
        :rtype: str
        """
        return self._due_date_type

    @due_date_type.setter
    def due_date_type(self, due_date_type):
        """Sets the due_date_type of this Schedule.

        the payment terms  # noqa: E501

        :param due_date_type: The due_date_type of this Schedule.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "DAYSAFTERBILLDATE",
            "DAYSAFTERBILLMONTH",
            "DAYSAFTERINVOICEDATE",
            "DAYSAFTERINVOICEMONTH",
            "OFCURRENTMONTH",
            "OFFOLLOWINGMONTH",
            "None",
        ]  # noqa: E501

        if due_date_type:
            if due_date_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `due_date_type` ({0}), must be one of {1}".format(  # noqa: E501
                        due_date_type, allowed_values
                    )
                )

        self._due_date_type = due_date_type

    @property
    def start_date(self):
        """Gets the start_date of this Schedule.  # noqa: E501

        Date the first invoice of the current version of the repeating schedule was generated (changes when repeating invoice is edited)  # noqa: E501

        :return: The start_date of this Schedule.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Schedule.

        Date the first invoice of the current version of the repeating schedule was generated (changes when repeating invoice is edited)  # noqa: E501

        :param start_date: The start_date of this Schedule.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def next_scheduled_date(self):
        """Gets the next_scheduled_date of this Schedule.  # noqa: E501

        The calendar date of the next invoice in the schedule to be generated  # noqa: E501

        :return: The next_scheduled_date of this Schedule.  # noqa: E501
        :rtype: date
        """
        return self._next_scheduled_date

    @next_scheduled_date.setter
    def next_scheduled_date(self, next_scheduled_date):
        """Sets the next_scheduled_date of this Schedule.

        The calendar date of the next invoice in the schedule to be generated  # noqa: E501

        :param next_scheduled_date: The next_scheduled_date of this Schedule.  # noqa: E501
        :type: date
        """

        self._next_scheduled_date = next_scheduled_date

    @property
    def end_date(self):
        """Gets the end_date of this Schedule.  # noqa: E501

        Invoice end date – only returned if the template has an end date set  # noqa: E501

        :return: The end_date of this Schedule.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Schedule.

        Invoice end date – only returned if the template has an end date set  # noqa: E501

        :param end_date: The end_date of this Schedule.  # noqa: E501
        :type: date
        """

        self._end_date = end_date



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class StatutoryDeduction(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "id": "str",
        "name": "str",
        "statutory_deduction_category": "StatutoryDeductionCategory",
        "liability_account_id": "str",
        "current_record": "bool",
    }

    attribute_map = {
        "id": "id",
        "name": "name",
        "statutory_deduction_category": "statutoryDeductionCategory",
        "liability_account_id": "liabilityAccountId",
        "current_record": "currentRecord",
    }

    def __init__(
        self,
        id=None,
        name=None,
        statutory_deduction_category=None,
        liability_account_id=None,
        current_record=None,
    ):  # noqa: E501
        """StatutoryDeduction - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._name = None
        self._statutory_deduction_category = None
        self._liability_account_id = None
        self._current_record = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if statutory_deduction_category is not None:
            self.statutory_deduction_category = statutory_deduction_category
        if liability_account_id is not None:
            self.liability_account_id = liability_account_id
        if current_record is not None:
            self.current_record = current_record

    @property
    def id(self):
        """Gets the id of this StatutoryDeduction.  # noqa: E501

        The Xero identifier for earnings order  # noqa: E501

        :return: The id of this StatutoryDeduction.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StatutoryDeduction.

        The Xero identifier for earnings order  # noqa: E501

        :param id: The id of this StatutoryDeduction.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this StatutoryDeduction.  # noqa: E501

        Name of the earnings order  # noqa: E501

        :return: The name of this StatutoryDeduction.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StatutoryDeduction.

        Name of the earnings order  # noqa: E501

        :param name: The name of this StatutoryDeduction.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def statutory_deduction_category(self):
        """Gets the statutory_deduction_category of this StatutoryDeduction.  # noqa: E501


        :return: The statutory_deduction_category of this StatutoryDeduction.  # noqa: E501
        :rtype: StatutoryDeductionCategory
        """
        return self._statutory_deduction_category

    @statutory_deduction_category.setter
    def statutory_deduction_category(self, statutory_deduction_category):
        """Sets the statutory_deduction_category of this StatutoryDeduction.


        :param statutory_deduction_category: The statutory_deduction_category of this StatutoryDeduction.  # noqa: E501
        :type: StatutoryDeductionCategory
        """

        self._statutory_deduction_category = statutory_deduction_category

    @property
    def liability_account_id(self):
        """Gets the liability_account_id of this StatutoryDeduction.  # noqa: E501

        Xero identifier for Liability Account  # noqa: E501

        :return: The liability_account_id of this StatutoryDeduction.  # noqa: E501
        :rtype: str
        """
        return self._liability_account_id

    @liability_account_id.setter
    def liability_account_id(self, liability_account_id):
        """Sets the liability_account_id of this StatutoryDeduction.

        Xero identifier for Liability Account  # noqa: E501

        :param liability_account_id: The liability_account_id of this StatutoryDeduction.  # noqa: E501
        :type: str
        """

        self._liability_account_id = liability_account_id

    @property
    def current_record(self):
        """Gets the current_record of this StatutoryDeduction.  # noqa: E501

        Identifier of a record is active or not.  # noqa: E501

        :return: The current_record of this StatutoryDeduction.  # noqa: E501
        :rtype: bool
        """
        return self._current_record

    @current_record.setter
    def current_record(self, current_record):
        """Sets the current_record of this StatutoryDeduction.

        Identifier of a record is active or not.  # noqa: E501

        :param current_record: The current_record of this StatutoryDeduction.  # noqa: E501
        :type: bool
        """

        self._current_record = current_record
